blob_id stringlengths 40 40 | directory_id stringlengths 40 40 | path stringlengths 3 264 | content_id stringlengths 40 40 | detected_licenses listlengths 0 85 | license_type stringclasses 2
values | repo_name stringlengths 5 140 | snapshot_id stringlengths 40 40 | revision_id stringlengths 40 40 | branch_name stringclasses 905
values | visit_date timestamp[us]date 2015-08-09 11:21:18 2023-09-06 10:45:07 | revision_date timestamp[us]date 1997-09-14 05:04:47 2023-09-17 19:19:19 | committer_date timestamp[us]date 1997-09-14 05:04:47 2023-09-06 06:22:19 | github_id int64 3.89k 681M ⌀ | star_events_count int64 0 209k | fork_events_count int64 0 110k | gha_license_id stringclasses 22
values | gha_event_created_at timestamp[us]date 2012-06-07 00:51:45 2023-09-14 21:58:39 ⌀ | gha_created_at timestamp[us]date 2008-03-27 23:40:48 2023-08-21 23:17:38 ⌀ | gha_language stringclasses 141
values | src_encoding stringclasses 34
values | language stringclasses 1
value | is_vendor bool 1
class | is_generated bool 2
classes | length_bytes int64 3 10.4M | extension stringclasses 115
values | content stringlengths 3 10.4M | authors listlengths 1 1 | author_id stringlengths 0 158 |
|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|
2d26b72373566709139cec8f4f238cf06fef4ba4 | 3f24da37878937bf884a971cde9209e7c0dc9211 | /chromecast/media/audio/cast_audio_output_stream.cc | eac009ceba3f2d7c18f62fab1aa35d614fd19508 | [
"BSD-3-Clause"
] | permissive | shenglihou/chromium | 5c4bab1a64163f4116dd9e1e590387d853dc982a | fb3cb75ead46b9979ac934f69ef05cad06fd11b1 | refs/heads/master | 2023-02-23T09:02:12.725032 | 2019-03-04T13:55:50 | 2019-03-04T13:55:50 | 173,755,773 | 1 | 0 | NOASSERTION | 2019-03-04T14:02:56 | 2019-03-04T14:02:54 | null | UTF-8 | C++ | false | false | 27,932 | cc | // Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "chromecast/media/audio/cast_audio_output_stream.h"
#include <algorithm>
#include <string>
#include <utility>
#include "base/bind.h"
#include "... | [
"commit-bot@chromium.org"
] | commit-bot@chromium.org |
03fb3e73f9a9b23231189270d87a469b3c399c81 | c4a65097b33ed3d810bdb5ff8005cd028d616fc9 | /1057/main.cpp | 63e9c80121a99ff406a848b6737e013f072cfc5a | [] | no_license | huangsunyang/PAT-A | 315c2e5d6e9657c5a5618ac46edf2663dce1da5f | 255c67c9c14f211c80bfc5bebe40dadc8a4b9fbf | refs/heads/master | 2020-12-04T12:45:02.951670 | 2016-12-07T08:54:32 | 2016-12-07T08:54:32 | 66,855,750 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,714 | cpp | //
// main.cpp
// 1057
//
// Created by huangsunyang on 11/19/2016.
// Copyright © 2016年 huangsunyang. All rights reserved.
//
#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;
int lowbit(int x) {
return x & -x;
}
int sum(int * a, int x) {
int ret = 0;
while (x > 0) {
... | [
"huangsunyang@126.com"
] | huangsunyang@126.com |
3a77f119e69692cfa873eccdf931a37c82d5331a | 06ace85cf18205fb1a3393e4b31335f526c54e64 | /history_orders/tradewrapper.cpp | 73a158bd5827fec571073ef1e29922aa000b923d | [] | no_license | handsomehu/CppWorkStream | db07a4030d7c79aabab56c0620d7ec9f8f197576 | 7db2dc4de37f24cc39cba6c9e95f641f64d4aef8 | refs/heads/master | 2021-06-25T21:45:38.351579 | 2021-01-29T08:35:19 | 2021-01-29T08:35:19 | 201,570,294 | 0 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 11,920 | cpp | #include "tradewrapper.h"
void NewTradeEvent()
{
}
TradeWrapper::TradeWrapper(const std::string &path):
m_ptraderapi(nullptr),
cfgpath(path), brokerid(""),mdaddress(""),tdaddress(""),
userid(""), password(""), appid(""),authcode(""),
jfile(path),isconnected(false),goodorder(false)
{
nlohmann::json j;
... | [
"leonzh18@hotmail.com"
] | leonzh18@hotmail.com |
45f4211ba2fed0143e4ae7f75bafc1d71387c3b5 | 4c7bfccc476ecca502e8bd1b09e4fcc2018bd786 | /Factory.cpp | 4d8e9aa89d4ebe92aae8672259b523d2dcfb6787 | [] | no_license | s3784464/APT-A2-M2 | d899b39ec2a74c1c778dba6dd4e524841efb1cf8 | faee1da78ef1fec2e75890c041d4d289062f5fb2 | refs/heads/master | 2022-09-27T00:45:57.242491 | 2020-06-05T11:23:58 | 2020-06-05T11:23:58 | 266,681,943 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,242 | cpp | #include "Factory.h"
Factory::Factory(int number)
{
this->number = number;
}
void Factory::addTile(Tile tile)
{
tiles.push_back(tile);
}
void Factory::addTile(Colour colour)
{
tiles.push_back(Tile(colour));
}
Row Factory::getAllTiles()
{
return tiles;
}
bool Factory::factoryContainsColour(Colour c... | [
"s3784464@student.rmit.edu.au"
] | s3784464@student.rmit.edu.au |
61566f781486b52b313e145391c5101852430272 | c43b08652839378b15cedcfb7ac34e2a4c135838 | /QT/firmas-build-desktop-Qt_4_8_2_in_PATH__System__Release/ui_mainwindow.h | 4cf402852be12cacecaf8172b2ca7f498b393f45 | [] | no_license | Akheon23/Sirio | 118b3104f1d0b554c44432fe019e74ee220d152b | 8e10da8efd21063d8ec8d7429ec7771b50311217 | refs/heads/master | 2021-01-17T08:32:33.501662 | 2014-01-31T15:17:15 | 2014-01-31T15:17:15 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,804 | h | /********************************************************************************
** Form generated from reading UI file 'mainwindow.ui'
**
** Created: Tue Jan 21 08:23:24 2014
** by: Qt User Interface Compiler version 4.8.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
******... | [
"alviurlex@gmail.com"
] | alviurlex@gmail.com |
8e11f449019c67ef88bfad4fbf39d966837486e5 | d93d66534aa153be6da764f5ab112fa522364da0 | /LanguageCompettion/main.cpp | b514e8ef2e8d9e75742a4a83e3e29e74c5d727d4 | [] | no_license | ramzan5/OOP | a7b79993a7c03523cb52417a2454a07e6051ccf5 | fce64dda1f592e3005661485b617b3b3d86c2233 | refs/heads/main | 2023-03-31T17:08:05.990705 | 2021-04-11T21:32:10 | 2021-04-11T21:32:10 | 349,256,149 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,548 | cpp | #include <iostream>
#include<string>
#include"competition.h"
#include"Enor.h"
#include"Enor1.h"
using namespace std;
void SolutionFor3(const string &file){
competition tt(file);
string Name;
int Year;
bool l;
for(tt.first();!tt.end();tt.next()){
//cout<<tt.current().year<<" "<<tt.current().... | [
"ramzanmechanical@gmail.com"
] | ramzanmechanical@gmail.com |
f4a46f2933945db386fad7107d5e173c200f76ee | ac1c9fbc1f1019efb19d0a8f3a088e8889f1e83c | /out/release/gen/third_party/perfetto/protos/perfetto/trace/chrome/chrome_trace_packet.pb.h | 24966c3f1e6d83e39fb1b57795ff85e93aef1011 | [
"BSD-3-Clause"
] | permissive | xueqiya/chromium_src | 5d20b4d3a2a0251c063a7fb9952195cda6d29e34 | d4aa7a8f0e07cfaa448fcad8c12b29242a615103 | refs/heads/main | 2022-07-30T03:15:14.818330 | 2021-01-16T16:47:22 | 2021-01-16T16:47:22 | 330,115,551 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | true | 36,147 | h | // Generated by the protocol buffer compiler. DO NOT EDIT!
// source: protos/perfetto/trace/chrome/chrome_trace_packet.proto
#ifndef GOOGLE_PROTOBUF_INCLUDED_protos_2fperfetto_2ftrace_2fchrome_2fchrome_5ftrace_5fpacket_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_protos_2fperfetto_2ftrace_2fchrome_2fchrome_5ftrace_5fpack... | [
"xueqi@zjmedia.net"
] | xueqi@zjmedia.net |
77262ed32f0a8cb7c1b8d2c96d90e341d6d3a25a | dbc2f341a9e9e0200f9a59e8b05a5cad0301e3ec | /script.cpp | f6f930813975ac4cf6059f7d9800583839474a21 | [] | no_license | JonSalazar/serialization | 3523e20abd521f2d7f36c0b88befbb76e9657db9 | e91f41505598ee37cec3cdbaa771f2f68fcd4368 | refs/heads/master | 2020-04-24T18:00:48.528153 | 2019-03-07T03:47:35 | 2019-03-07T03:47:35 | 172,166,665 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 13,766 | cpp | // Copyright (c) 2009-2010 Satoshi Nakamoto
// Copyright (c) 2009-2017 The Bitcoin Core developers
// Distributed under the MIT software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
#include "script.h"
#include "tinyformat.h"
#include "utilstrencodings.h"
names... | [
"jonsalazar99@hotmail.com"
] | jonsalazar99@hotmail.com |
cb22396796a2a250966f770f187319bc1ca387ed | 4ea9eefe2b8a8e7fa0d1096a93f316f158592614 | /rpm_reader.ino/rpm_reader.ino.ino | dc779e8a78c96183d858918041b9281f045dd07a | [] | no_license | kokhouse/laser | 0b4aa61e890de3ef8004f7a4759ca3e206e19afa | 540eb8856d0a27e48e4ce07e78e42f2077eb6e32 | refs/heads/master | 2021-06-19T07:51:10.887750 | 2017-05-22T02:33:55 | 2017-05-22T02:33:55 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 965 | ino | /*
This was a small project to measure the rpm and stats of fidget spinners. Just input the radius of your fidget spinner below and that's it!
This processing script reads the input buffer for readings of rpm from the hardware (Arduino).
You'll also need to create the hardware for it, there's an arduino file that ... | [
"dovescrymgmt@gmail.com"
] | dovescrymgmt@gmail.com |
8842de40196a9520af95c98955f0800a78ae3158 | 22db797fd057fa00a9c79cfcd233a45719ff5a1f | /UnsungWarriors/winAPI/cave2.h | 63817922455098a92636fd0c4170cdc43bd19bb9 | [] | no_license | gooddaeking/unsungwarriors | 635a1f4fc87e142ef42d8946f6b98a43e6a2cc24 | 833d51fe3bdbea758a8f01a02bcb16e1788b3ae8 | refs/heads/master | 2022-11-17T09:53:34.219721 | 2020-07-17T07:08:06 | 2020-07-17T07:08:06 | 280,351,521 | 0 | 0 | null | null | null | null | UHC | C++ | false | false | 561 | h | #pragma once
#include "gameNode.h"
#include "player.h"
#include "enemyManager.h"
class cave2 : public gameNode
{
private:
player* _player; //플레이어 클래스
enemyManager* _enemyManager; //적매니져 클래스
image* _cave2;
image* _collision;
RECT _backGround;
float _x, _y;
float _colX, _colY;
int _width, _height;
int _count;... | [
"gooddaeking@gmail.com"
] | gooddaeking@gmail.com |
0f02f46d6a18c7b093948e4a75dde6841389b7db | 05688de8dd33283bbf09a67edfb4acd53a1f2376 | /PlayPcmWin/WasapiIODLL/WasapiIOIF.cpp | f32f3f5d0666e3080f103396c34d0a1aaccd132c | [
"MIT"
] | permissive | jcreator35/PlayPcmWin | f72da2d586dcca05499aae2bb2974b36739261c9 | 4296c2093a28808fe67b39943f580ead0a207fb9 | refs/heads/master | 2021-06-24T00:59:37.305328 | 2020-11-21T16:49:20 | 2020-11-21T16:49:20 | 317,008,535 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 21,547 | cpp | // 日本語。
#include "WasapiIOIF.h"
#include "WasapiUser.h"
#include "WWPlayPcmGroup.h"
#include "WWWasapiIOUtil.h"
#include "WWTimerResolution.h"
#include "WWAudioDeviceEnumerator.h"
#include "WWAudioFilterType.h"
#include "WWAudioFilterPolarityInvert.h"
#include "WWAudioFilterMonauralMix.h"
#include "WWAudioF... | [
"yamamoto2002@7aea3531-1b4f-4469-99c4-25ca468c163d"
] | yamamoto2002@7aea3531-1b4f-4469-99c4-25ca468c163d |
17f806ab28776ed2f6e5826e036a3f0092b54d77 | 9cd9275bd4378ad36a6ea39ccc5c37160e1f0f76 | /HW2/HW2.cpp | 1f3f5fd4f515dcc4b54b714a986f510b56fd3368 | [] | no_license | suda999/Udacity_CS344_Introduction_to_Parallel_Programming | 5e9eea8921f8c1eb99eecc4e4d6bfc5f8397fe63 | 24baf89a045ae5fcbdbe89de42c914dbf7941f5e | refs/heads/master | 2021-01-18T14:42:38.868061 | 2013-02-16T18:09:36 | 2013-02-16T18:09:36 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 5,312 | cpp | //Udacity HW2 Driver
#pragma once
#include "stdafx.h"
#include <iostream>
#include "timer.h"
#include "utils.h"
#include <string>
#include <stdio.h>
#include <opencv2/core/core.hpp>
#include <opencv2/highgui/highgui.hpp>
#include <opencv2/opencv.hpp>
#include <cuda.h>
#include <cuda_runtime.h>
void your_gaussian_blur(... | [
"alexandre.pestana@supinfo.com"
] | alexandre.pestana@supinfo.com |
02f07b31546e05c74e724bb32b86c6d08c4b9a4a | adefab1f540aee6a245b250ea660faa618513431 | /dbms/include/DB/Storages/MergeTree/MergeTreeSharder.h | 18549f4e8137979cc7b0e7eeb69e8601a9b79a1e | [
"Apache-2.0"
] | permissive | SevaCode/ClickHouse | 23b6ba4f3ae9ed62807dcdd8e5d3bae68c8e038b | 08cb8e506b49aef6ae2086be8947f728450c4d73 | refs/heads/master | 2020-06-14T15:16:59.282376 | 2016-11-29T19:28:50 | 2016-11-29T19:28:50 | 75,167,027 | 0 | 0 | NOASSERTION | 2019-03-14T09:46:11 | 2016-11-30T08:29:42 | C++ | UTF-8 | C++ | false | false | 1,824 | h | #pragma once
#include <DB/IO/WriteBufferFromFile.h>
#include <DB/IO/CompressedWriteBuffer.h>
#include <DB/Columns/ColumnsNumber.h>
#include <DB/Interpreters/sortBlock.h>
#include <DB/Storages/MergeTree/MergeTreeData.h>
#include <DB/Core/Block.h>
namespace DB
{
struct ShardedBlockWithDateInterval final
{
ShardedBloc... | [
"milovidov@yandex-team.ru"
] | milovidov@yandex-team.ru |
b9fee651b078f8d8c3491333fab64dc7e696153f | 279513e370e9f6e64707d25b3f6f13edc45509ff | /cpp_03/ex00/FragTrap.cpp | 0b8c98bdae6e0abf6db31650039330be9abc5ff0 | [] | no_license | Tokmachov/cPlusPlusPiscine | 22a87c28eedcdce39bd1419472ff28e3ba6c7f23 | 87fa79f2b7c2aab57fcf810837ff35256c717fad | refs/heads/master | 2023-06-17T04:05:11.076008 | 2021-07-09T14:04:53 | 2021-07-09T14:04:53 | 384,453,109 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 7,037 | cpp | /* ************************************************************************** */
/* */
/* ::: :::::::: */
/* FragTrap.cpp :+: :+: :+: ... | [
"oleg.tokmachov@icloud.com"
] | oleg.tokmachov@icloud.com |
4ca0f466be191dc002630cb85f6b9dc8c80905c9 | 3a2dd5d4d7e742f3c2d305c475102e3336d0c8f0 | /code/leetcode/2020-09-20_zijie01.cpp | dfedac3243383f3a6a528c6e421b22d322a70670 | [] | no_license | jia-hao-liu/Learning-Note | 719b1783eec9933fac4232b73f2b70a28b1dd55f | a508196545885d4de96af9c1963506b97448bb31 | refs/heads/master | 2022-12-22T20:16:46.037934 | 2020-10-05T04:11:11 | 2020-10-05T04:11:11 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,440 | cpp |
/*
最短循环字串
查找字符串中是否能够由最短的字符串循环组成
可以则输出最短的循环字符串
否则就输出原字符串
abababab
ab
*/
#include <cmath>
#include <cctype>
#include <cstring>
#include <sstream>
#include <iostream>
#include <map>
#include <vector>
#include <stack>
#include <queue>
#include <unordered_map>
#include <unordered_set>
#include <algorithm>
#include <thread... | [
"wangpengcheng2018@gmail.com"
] | wangpengcheng2018@gmail.com |
3f2907785f1f2013c15dc5d1838f8313cb769aff | 47503dd5bf45a2136caa7f0d7bbe22b51a6915ce | /C++_Solutions/Codeforces/Codeforces_Round/655/d-omkar-and-circle.cpp | eebfc03d1bcce1589d45ba94acee6976ba06b884 | [] | no_license | TheKillerAboy/programming-olympiad | 7657f67da0ec6c24d61a58bc9f1cd985fbc7185d | 78980db0cf35b324d47e8eab1f8ae4e441f5ab7d | refs/heads/master | 2021-12-28T22:17:59.131008 | 2021-10-25T08:06:01 | 2021-10-25T08:06:01 | 182,806,301 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,902 | cpp | #include <bits/stdc++.h>
using namespace std;
#define FOR(i_,a_) for(long long i_=0;i_<a_;++i_)
#define FORS(s_,i_,a_) for(long long i_=s_;i_<a_;++i_)
#define FORR(i_,a_) for(long long i_=a_-1;i_>=0;--i_)
#define FORI(i_,a_) for(long long i_=1;i_<=a_;++i_)
#define FORA(i_,a_) for(auto i_:a_)
#define FOR1(i_,a_) for(l... | [
"annekin001@gmail.com"
] | annekin001@gmail.com |
b449d67c1267b04290108e7e2678f3cb048099f4 | 1b063955be078b863da3f5c7844f029c473a394d | /ArduinoMEGA/RFIDModule/MF-RC522_RFID/MF-RC522_RFID.ino | 0e60715c1d4ed56c2902900f91bdadc56e3576b2 | [] | no_license | ThorbenQuast/ArduinoFun | 197d1ffd9083cc27bb8219dfd6585433538aa12c | b671dec4fe8ded739ba1ac5bf78c855e03f873aa | refs/heads/master | 2022-02-18T05:46:13.391437 | 2022-02-13T17:23:52 | 2022-02-13T17:23:52 | 130,761,498 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 4,207 | ino | //www.elegoo.com
//2016.12.09
/*
* --------------------------------------------------------------------------------------------------------------------
* Example to change UID of changeable MIFARE card.
* ---------------------------------------------------------------------------------------------------------------... | [
"thorbenquast@MacBook-Pro.local"
] | thorbenquast@MacBook-Pro.local |
8ab2a0d4f086451df94620dac74a84272aa8432c | 711e0d680b6a659ecc703bd05db17fbf41a7284f | /cpp/Bigger is Greater.cpp | 2566d6cec37e83388e550aaa29bc28dd75b827b5 | [] | no_license | pluralism/hackerrank | d3448f1777e5c493820f94d9b31d0f5f1cbf4a07 | e46a17fc421537ade74ddeae77a13bd6a4c37641 | refs/heads/master | 2021-01-19T03:09:08.654707 | 2019-10-06T11:29:36 | 2019-10-06T11:29:36 | 46,612,415 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 421 | cpp | #include <iostream>
#include <string>
#include <algorithm>
using namespace std;
string evaluate(string s)
{
bool valid = false;
for (int i = s.size() - 1; i > 0; i--)
if (s[i] > s[i - 1])
{
next_permutation(s.begin(), s.end());
return s;
}
return "no answer";
}
int main(int argc, char *argv[])
{
int ... | [
"andrepdpinheiro@gmail.com"
] | andrepdpinheiro@gmail.com |
2d9db5e3fb9422cd345df94b049a1b10b31fae33 | bf9d696dd64846d5773b5a0156aff9b633d607de | /LongestCommonSubsequence(Iterative).cpp | db22e7a228541a9760121b695000b22975b7f41f | [] | no_license | knbdtu/Algorithms-Library | db6f96199beb657d354dfa3a76d078141c09d6c3 | b08e674fd00e6910c5d185a480d816150972f75b | refs/heads/master | 2020-12-29T02:36:50.804278 | 2018-03-14T11:52:22 | 2018-03-14T11:52:22 | 50,768,659 | 1 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 896 | cpp | #include<bits/stdc++.h>
using namespace std;
#define LL long long
#define mp make_pair
#define pb push_back
#define mt make_tuple
#define LD long double
#define gc getchar_unlocked
#define pc putchar_unlocked
#define MOD 1000000007
#define MAXN 2*100005
#define bitcount __builtin_popcount
#define INF 2000000000
#define... | [
"knbdtu@hotmail.com"
] | knbdtu@hotmail.com |
7a830a9d895c5f680342afd7ca29731ab1dd3f2d | bd7d4c148df27f8be6649d313efb24f536b7cf34 | /src/armnn/backends/RefWorkloads/FullyConnected.hpp | fa6f54a3ec0a7baf03ae44e6eb3392fe3e1f18c4 | [
"MIT"
] | permissive | codeaudit/armnn | 701e126a11720760ee8209cc866aa095554696c2 | c577f2c6a3b4ddb6ba87a882723c53a248afbeba | refs/heads/master | 2020-03-29T00:48:17.399665 | 2018-08-31T08:22:23 | 2018-08-31T08:22:23 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 644 | hpp | //
// Copyright © 2017 Arm Ltd. All rights reserved.
// See LICENSE file in the project root for full license information.
//
#pragma once
#include <armnn/Tensor.hpp>
namespace armnn
{
/// Performs a matrix multiplication and optionally adds a bias.
void FullyConnected(const float* inputData,
... | [
"telmo.soares@arm.com"
] | telmo.soares@arm.com |
714e67ff6406d5d54e559cec39d8938e0963fdd7 | 980348abab32f50717ca0d5603dd0af22ad6c823 | /Scanner.h | 5e2dad12dbe15853ef5691b48fdbb7aaf887b0a2 | [] | no_license | JosephSummerhays/cs-236 | f924572b61f987d614cd7daf4fa2b8fd74857751 | 22a67b1ae2dd6c24735210e533b421c2a5183b45 | refs/heads/master | 2021-09-11T21:56:38.829216 | 2018-04-12T17:38:33 | 2018-04-12T17:38:33 | 125,928,775 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 582 | h | #pragma once
#include "charList.h"
#include "token.h"
#include <vector>
using namespace std;
class Scanner {
private:
vector<Token*> tokenList;
charList daChars;
bool getString(string& toReturn);
bool getSingleComment(string& toReturn);
bool getMultiComment(string& toReturn);
void getID(string& toReturn);
... | [
"summerhays.joseph@gmail.com"
] | summerhays.joseph@gmail.com |
3e66475313d4ccfd2fdbb2a1f0db0afdfdef7d50 | 0eff74b05b60098333ad66cf801bdd93becc9ea4 | /second/download/mutt/gumtree/mutt_repos_function_856_mutt-1.4.2.3.cpp | dbefaca24274c369b33b6857a6e5662ac6225313 | [] | no_license | niuxu18/logTracker-old | 97543445ea7e414ed40bdc681239365d33418975 | f2b060f13a0295387fe02187543db124916eb446 | refs/heads/master | 2021-09-13T21:39:37.686481 | 2017-12-11T03:36:34 | 2017-12-11T03:36:34 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,232 | cpp | int rfc822_valid_msgid (const char *msgid)
{
/* msg-id = "<" addr-spec ">"
* addr-spec = local-part "@" domain
* local-part = word *("." word)
* word = atom / quoted-string
* atom = 1*<any CHAR except specials, SPACE and CTLs>
* CHAR = ( 0.-127. )
* spe... | [
"993273596@qq.com"
] | 993273596@qq.com |
8497254e4e80f3577800e437eef61aeee864ac07 | 4e035c6d51fa19cbdf4f584867b55e7813b69869 | /src/Menu/Custom/HUDInfo.cpp | 1df440391df2d3ca95941e0f6894d020b38a9ea9 | [] | no_license | ipoopedmypantsuups/HitmanAbsolutionSDK | d28ec117f8da8c2f1bab3068a17c7143c5f83ea4 | c4a211550dc66687df9bdae5d4c0bf665d48f5ad | refs/heads/main | 2023-03-08T05:04:24.939062 | 2021-02-20T08:07:30 | 2021-02-20T08:07:30 | 359,103,783 | 0 | 0 | null | 2021-04-18T09:50:59 | 2021-04-18T09:50:58 | null | UTF-8 | C++ | false | false | 16,447 | cpp | #include "HUDInfo.h"
static ImVector<__int16> textIDList;
void HUDInfo::DrawWindow(bool* showHUDInfo)
{
ImGui::SetNextWindowSize(ImVec2(640, 480), ImGuiCond_FirstUseEver);
if (!ImGui::Begin("HUD Info", showHUDInfo))
{
ImGui::End();
return;
}
ZHUDManager* hudManager = reinterpret_cast<ZHUDManager*>(Globals:... | [
"pavle_nis@yahoo.com"
] | pavle_nis@yahoo.com |
08b1c07e89902aed7523ff28b5bd4b36ab78d8de | 60a15a584b00895e47628c5a485bd1f14cfeebbe | /comps/misc/SpermParams/dpoint.h | e9d129ffb7b4ada62c9b8147096e0924ad1027bc | [] | no_license | fcccode/vt5 | ce4c1d8fe819715f2580586c8113cfedf2ab44ac | c88049949ebb999304f0fc7648f3d03f6501c65b | refs/heads/master | 2020-09-27T22:56:55.348501 | 2019-06-17T20:39:46 | 2019-06-17T20:39:46 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,742 | h | #if !defined(AFX_DPOINT_H__CE6E9F95_2085_45C9_90EA_B442BFB1EF56__INCLUDED_)
#define AFX_DPOINT_H__CE6E9F95_2085_45C9_90EA_B442BFB1EF56__INCLUDED_
#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
#include "misc_utils.h"
typedef struct tagDPOINT
{
double x;
double y;
} DPOINT, *PDPOINT, NEAR *NPDPO... | [
"videotestc@gmail.com"
] | videotestc@gmail.com |
0e6de7e04aa1295eb8bc8566c7460b1eb4a1f641 | dc47f4f3e1966afc6c2af6155750bda6efcf087d | /src/utils/Singleton.hpp | cc9c7b3351740d70904be006cfe1d055299c2ea7 | [] | no_license | mistickpulse/LifeIsBorneAlpha | 2974036fc7e543bc8efa2b81566b3313753f94b5 | 81c7890931952d2aac57b4a483597b19243a63c5 | refs/heads/master | 2022-03-07T21:04:38.615270 | 2019-09-26T14:12:01 | 2019-09-26T14:12:01 | 110,580,338 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 344 | hpp | //
// Created by zouz on 28/01/18.
//
#ifndef LIFEISBORNE_SINGLETON_HPP
#define LIFEISBORNE_SINGLETON_HPP
#include "NonCopyable.hpp"
template <typename T>
class Singleton
{
public:
virtual ~Singleton() = default;
static T &getInstance()
{
static T inst;
return inst;
}
};
#endif //LI... | [
"fabian.le-maux@epitech.eu"
] | fabian.le-maux@epitech.eu |
b68b0123b869c60afa7f691fddcf697bf728c05f | 127929127483e0263242a9dd187c7e0d2548be7f | /Computação Gráfica/TP_Fase3/Build/parser.h | cd93d5c135f7edac8d1b8a2b2a89a9283b812f04 | [] | no_license | chico2911/MIEI | fce493c77fb3f4657c940f7abfcac6da3d314eaa | c7618d585825e9e10d766eeb51d77773a0420c5c | refs/heads/main | 2023-06-17T06:11:23.538885 | 2021-02-28T17:10:59 | 2021-02-28T17:10:59 | 333,534,779 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 353 | h | #ifndef CG_TP_PARSER_H
#define CG_TP_PARSER_H
#include <iostream>
#include <string.h>
#include "tinyxml2.h"
#include "operations.h"
using namespace std;
using namespace tinyxml2;
void parseGroup(const XMLElement* child, Group g, int i, vector<OperFile*>& files);
void xmlParser(const char* config, vector<OperFile*>&... | [
"a85367@alunos.uminho.pt"
] | a85367@alunos.uminho.pt |
1690985616f0acade7f4ff2992cb6ce2334a1614 | b3ca66d5ef591564f33c75e2e551276824a7c37c | /src/protocol.h | 7b825bd7e0fb25a1ca87667d493a80cafd401e57 | [
"MIT"
] | permissive | autocoin/autocoin | 5e859487a89ce7ec865be4978c388acf5ad544f9 | 0e2780033b1b3dc214ee02bf7c3a3911b214ef86 | refs/heads/master | 2020-05-16T22:13:10.761883 | 2014-02-09T16:10:48 | 2014-02-09T16:10:48 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 3,719 | h | // Copyright (c) 2009-2010 Satoshi Nakamoto
// Copyright (c) 2009-2012 The Bitcoin developers
// Distributed under the MIT/X11 software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
#ifndef __cplusplus
# error This header can only be compiled as C++.
#endif
#ifnd... | [
"inmean@manichgroup.com"
] | inmean@manichgroup.com |
3fb7f5a4cfa2b9572c7d872c3ea8d277781db770 | 114020ebc487ba101948951e947a738f665fe68c | /src/QCPF_Plugins/QCPF_ViewEditor/PluginIO.h | ca5145e53f04e47a91c37e5dce462a12255ac1b3 | [] | no_license | 519984307/QCPFrame | 02df7947574e3c48bc5fdb8b012b894b98fb7a91 | 75a69ecac69e7572738dee447f158034015f148c | refs/heads/master | 2023-03-22T01:33:33.124364 | 2020-12-22T07:53:48 | 2020-12-22T07:53:48 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 862 | h | /*
Author : Jamie.Tong
QQ : 260271262
Data : 2020-09-07
License: GPL v3.0
*/
#ifndef QPLUGIN1_H
#define QPLUGIN1_H
#include "../../QCPF_PluginModel/qcpf_systempluginmodel.h"
class MyClass
{
public:
int Var1;
QString Var2;
double Var3;
};
Q_DECLARE_METATYPE(MyClass)
class PluginIO : public QCPF_... | [
"260271262@qq.com"
] | 260271262@qq.com |
b18668e426edb5378264806b4f99b26423a2baf8 | 9b4571b17e489dda945ce09da80e7d52552d91b9 | /ChardChess/Knight.hpp | 5b31b2b9857b3c1da59329e77a43c58d297cd67b | [] | no_license | mattyan1053/CardChess | 5d79e271f09953da223e0f20a08f4efbec30e373 | acd91a2fcd36bf5514cdcb93c22f0bcbe02b0074 | refs/heads/master | 2020-06-20T06:32:59.011256 | 2019-12-20T11:33:34 | 2019-12-20T11:33:34 | 197,026,951 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 204 | hpp | # pragma once
# include "Piece.hpp"
# include "Board.hpp"
namespace Game {
class Knight : public Piece {
public:
Knight(Turn _owner);
Array<Point> getMovable(Point pos, const Board& b);
};
} | [
"h.matsumaruka14161@gmail.com"
] | h.matsumaruka14161@gmail.com |
0261f03644190c8d203239953cf0b50b04c25b3c | 32b2b407933f4c19e62b669ba4fdbd3b438e6796 | /source/ERIndex/src/EncryptedFileBitWriter.cpp | 6bc8515195435761fbf2396048ba503986632558 | [] | no_license | EncryptedIndexes/erindex | 3b01636aa2817e1605932e0ef228e8ee2f966490 | b1b77751731912f44d8f8c86461e1431121b04b6 | refs/heads/master | 2020-06-30T02:08:27.224812 | 2019-09-15T07:30:21 | 2019-09-15T07:30:21 | 200,687,557 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,119 | cpp | /*
* EncryptedFileBitWriter.cpp
*
* Created on: 27/nov/2014
* Author: fernando
*/
#include "EncryptedFileBitWriter.h"
#include "EncryptionContext.h"
#include "../srcSalsa20/ecrypt-sync.h"
namespace std {
void EncryptedFileBitWriter::ECRYPT_ctrsetup(ECRYPT_ctx *x,const u8 *ctr)
{
x->input[8] = U8TO32_BIG... | [
"fernando@DESKTOP-TNPPO1S.localdomain"
] | fernando@DESKTOP-TNPPO1S.localdomain |
d585933c6e0c78d44b416711eaa4b8e438286c08 | 35ce17fea858e03da2d96015e77735c67c5c5820 | /Sofware/c++/roadmapp/Basic Operations/bitwise.cpp | e8c8358d598bfbadf1ff593744059fd6c56a567a | [] | no_license | Ciaran-06/CPP-RoadMap | 5995ad9d5a34ef43c55c86084d835355068188d5 | 9b46ddb2a4e188bb33640b0c53a26d66ea8dad24 | refs/heads/main | 2023-09-06T09:20:40.686564 | 2021-11-18T18:52:36 | 2021-11-18T18:52:36 | 429,173,573 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 517 | cpp | #include <iostream>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
int main()
{
int x = 5, y = 1;
std::cout << "x = " << x << "," << " y = " << y << std::endl;
std::cout << "x & y = " << (x & y) << std::endl;
std::cout << "x | y = " << (x | y) << std::endl;
std::cout << "x ^ y = " << (... | [
"76187734+Ciaran-06@users.noreply.github.com"
] | 76187734+Ciaran-06@users.noreply.github.com |
8eed450353e1037dbbb72d21b63cdc49b8aa4a26 | dd656493066344e70123776c2cc31dd13f31c1d8 | /MITK/Modules/MitkExt/Interactions/mitkCreateSurfaceTool.cpp | a29655c327893daada0d77ae17b13eed59b2c19d | [] | no_license | david-guerrero/MITK | e9832b830cbcdd94030d2969aaed45da841ffc8c | e5fbc9993f7a7032fc936f29bc59ca296b4945ce | refs/heads/master | 2020-04-24T19:08:37.405353 | 2011-11-13T22:25:21 | 2011-11-13T22:25:21 | 2,372,730 | 0 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 3,093 | cpp | /*=========================================================================
Program: Medical Imaging & Interaction Toolkit
Language: C++
Date: $Date$
Version: $Revision: 1.12 $
Copyright (c) German Cancer Research Center, Division of Medical and
Biological Informatics. All rights reserved.
See MITKCopyrig... | [
"dav@live.ca"
] | dav@live.ca |
b39112ae2618cb027b9b33914a8a61ddc422bebb | c7c2d1b63d4e5c721f34eca6cfd1398db5bf5e64 | /PBL_Engine/SkyboxCbuf.h | dddfc1fb679063cac7a8359d0dbef47e3830062e | [] | no_license | AdamJozwiak/PBL_Endless_Project | 365ed80ce724a9a1f844212de26eb8d4718a72ef | 96fba2d2d78f745df98160e470d28f7d4c050633 | refs/heads/master | 2021-07-22T17:05:20.737893 | 2020-06-29T19:41:39 | 2020-06-29T19:56:28 | 245,690,594 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 541 | h | #pragma once
#include <DirectXMath.h>
#include "ConstantBuffers.h"
#include "Renderable.h"
struct Skybox;
class SkyboxCbuf : public Bindable {
private:
struct Transforms {
float animationSpeed;
float padding[3];
};
public:
SkyboxCbuf(Graphics& gfx, const Renderable& parent, Skybox* s... | [
"TomaszMWitczak@gmail.com"
] | TomaszMWitczak@gmail.com |
971f2ada7e6b3c390044048ac704bf3a400474cb | 235a45e530dd2fdc307c9c187fb95283e9738f33 | /src/Game.cpp | 34d39bf63bd62e013404af27754f0a7bde782ad5 | [] | no_license | CampbellOwen/sdl2-game | 936f5bf279bbc8f3f073fda2381cc24b23befc14 | a3106e98faacf32b532a54d39b6566038063af89 | refs/heads/master | 2016-09-01T03:24:06.103281 | 2016-02-12T02:04:25 | 2016-02-12T02:04:25 | 49,812,722 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,542 | cpp | #include "Game.h"
#include <iostream>
#include "mTexture.h"
#include "Player.h"
const int RENDER_WIDTH = 1920;
const int RENDER_HEIGHT = 1080;
const int WINDOW_WIDTH = 1366;
const int WINDOW_HEIGHT = 768;
SDL_Renderer* renderer;
SDL_Window* window;
mTexture playerTexture;
Player player;
TTF_Font* gFont = NULL;
mTe... | [
"ocampbel@sfu.ca"
] | ocampbel@sfu.ca |
14347e043ae0bc808312524d899a97897a192a30 | 1d7c16fe21d4b8ba1e5a58b483a2b0614260dad3 | /Source/SurfaceFootstepSystem/Public/FootstepInterface.h | aa606dbb7dc681afaeba047de8c4e7ea665e6fdc | [] | no_license | ChuniMuni/SurfaceFootstepSystem | 60b5dc5a4bf53c217e734a58dfb3d55e6c2b88a0 | dcc11def29215535f795667ed4cb2f666bb1046a | refs/heads/master | 2021-05-21T05:47:08.266622 | 2019-12-20T20:06:46 | 2019-12-20T20:06:46 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 717 | h | // Copyright 2019 Urszula Kustra. All Rights Reserved.
#pragma once
#include "CoreMinimal.h"
#include "UObject/Interface.h"
#include "FootstepInterface.generated.h"
class UFootstepComponent;
class UFoostepPoolingManagerComponent;
UINTERFACE(BlueprintType)
class UFootstepInterface : public UInterface
{
GENERATED_UI... | [
"kustra.u@gmail.com"
] | kustra.u@gmail.com |
b44091fc5d1633815f13dd19a3970867bc8dd954 | 1c59d5ce5fe68ea1aa3c0339d9972988ac50ba8d | /main.cpp | 6aaac4f5d7979cb4debe011577162ba916997a39 | [] | no_license | magickreeator/uIME-qtdicgen | 34e99cccad0a7a818ea19a39d5d23b2479958ae9 | 228a96905f91d35ac88dbc5bdbcb323c5d48410c | refs/heads/master | 2020-05-21T08:45:39.847223 | 2015-06-20T21:38:12 | 2015-06-20T21:38:12 | 37,786,843 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,538 | cpp | #include <QCoreApplication>
#include <QFile>
#include <QTextStream>
int main(int argc, char *argv[])
{
QCoreApplication a(argc, argv);
QString en = "qwertyuiop[]asdfghjkl;'zxcvbnm,./`1234567890-= !@#$%^&*()_+!\"№;%:?*()_+~QWERTYUIOP{}ASDFGHJKL:\"ZXCVBNM<>?\\|";
QString ru = "йцукенгшщзхъфывапролджэячсмить... | [
"magickreeator@gmail.com"
] | magickreeator@gmail.com |
42c8535ccfd6099639caf1555e8d2ef3ec62a51b | 5e6637b14fa372049196b4fdbea0bd03ef6180cb | /oj题目/www.acmicpc.sdnu.edu.cn/xx1070.cpp | ecf023740174b3037844fa21d22e228b745c9a13 | [] | no_license | dangfugui/note-C | de1d9ad34b7ad5e804f41093a6fade408ac56ef5 | 0cfce2b3f06749312ef22e965bf29f6ed1783f0a | refs/heads/master | 2020-06-23T13:41:00.370822 | 2016-09-10T14:24:26 | 2016-09-10T14:24:26 | 67,228,867 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 262 | cpp | #include<iostream>
using namespace std;
void ex(int *a,int *b)
{
int c;
c=*a;
*a=*b;
*b=c;
}
int main()
{
int a,b;
int *d,*f;
cin>>a>>b;
d=&a;
f=&b;
ex(d,f);
cout<<a<<endl<<b<<endl;
return 0;
}
| [
"dangfugui@163.com"
] | dangfugui@163.com |
11efefd9c34f1f857ad092b53c33db10cab8afa1 | 62510fa67d0ca78082109a861b6948206252c885 | /hihope_neptune-oh_hid/00_src/v0.1/applications/sample/camera/launcher/launcher/src/main/cpp/main_ability_slice.h | e7adda8a1b44d8b651f6dbbf9c30a000db3bdd0c | [
"Apache-2.0"
] | permissive | dawmlight/vendor_oh_fun | a869e7efb761e54a62f509b25921e019e237219b | bc9fb50920f06cd4c27399f60076f5793043c77d | refs/heads/master | 2023-08-05T09:25:33.485332 | 2021-09-10T10:57:48 | 2021-09-10T10:57:48 | 406,236,565 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,725 | h | /*
* Copyright (c) 2020 Huawei Device Co., Ltd.
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law ... | [
"liu_xiyao@hoperun.com"
] | liu_xiyao@hoperun.com |
4b54062efdd3ec8cf7ee7cd30d0ce6f264af2fe8 | 3766011a9471dc9f7ade6d13c04fefb781e0a899 | /retrace/play.hpp | 3c7bfb84527c17e50c9bda2a9c0cea870cd82ed8 | [
"MIT"
] | permissive | casseveritt/apitrace | 9a95600eb8a2fc3af85f5e528bb72d9436047a57 | 75d85d6f2fccb3da7c33d248830d8f6e8fb18c87 | refs/heads/master | 2021-01-18T18:49:02.558821 | 2014-03-01T16:16:50 | 2014-03-01T16:16:50 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 4,871 | hpp | /**************************************************************************
*
* Copyright 2011-2012 Jose Fonseca
* Copyright (C) 2013 Intel Corporation. All rights reversed.
* Author: Shuang He <shuang.he@intel.com>
* All Rights Reserved.
*
* Permission is hereby granted, free of charge, to any person obtaining ... | [
"cass@xyzw.us"
] | cass@xyzw.us |
8964746c104760f50bc3fc46569a354154b7dd88 | 2c4fec686fbe909fc27e168ecd115280f3fefc5d | /cpp-test/huawei/36011.cpp | 12ff03c3c1f2a1b61bd64ba9857ede228ec55ea6 | [] | no_license | mianhk/learn_cpp | 346196ec15df2a5d7db31d57b29a56297f7995b6 | 09686fba74195e85b1112b590d375aaf44a5166c | refs/heads/master | 2021-10-08T12:51:03.198670 | 2018-12-12T12:41:29 | 2018-12-12T12:41:29 | 91,341,701 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 442 | cpp | #include <bits/stdc++.h>
using namespace std;
int main(int argc, char const *argv[])
{
int n;
while(cin>>n){
int l1=0,l2=0,h1=0,h2=0;
int temp1,tem2;
cin>>temp1>>temp2;
if(temp1<l1)
l1=temp1;
if(temp1>l2)
l2=temp1;
if(temp2<h1)
h1=te... | [
"gcyu25@gmail.com"
] | gcyu25@gmail.com |
208fe460abbf86e2a5ec078915834fc849c1d22c | 9610fd0ee6cccbd5e7ec9a0c4439fbf80e629555 | /UpdateSystem/include/UpdateSystem/Hasher/FileHashInterface.h | f8752be3d2f4abe6236e3a0181d8e419112feedb | [
"Apache-2.0"
] | permissive | ProtocolONE/cord.update-system | eaefb45bdc76e91607b065f453f4a3ab9cfff5aa | ec14aa3210f41f788d2ea3229d36bff7f0b327d0 | refs/heads/master | 2020-04-07T17:31:38.043228 | 2018-11-27T08:28:43 | 2018-11-27T08:28:43 | 158,572,786 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 300 | h | #pragma once
#include <UpdateSystem/UpdateSystem_global.h>
#include <QtCore/QString>
namespace P1 {
namespace Hasher {
class UPDATESYSTEMSHARED_EXPORT FileHashInterface {
public:
~FileHashInterface() {}
virtual QString getFileHash(const QString& filePath) = 0;
};
}
}
| [
"Clipeus@live.com"
] | Clipeus@live.com |
38d21c26a3701ab78918ada331edcab1f921bfe3 | 86a085fbf5abde1d7d37450b1f4c828260b19234 | /ch01/c1_4_06.2.cpp | 39771b0e064f59df9247cb1d163a4a3c5d5fe8ca | [] | no_license | crespo2014/cpp-exam | 5eaa0f87e5839988974774a3766940bd3adfbf6f | 8794f2945494873c610b6938571b13463c74e22a | refs/heads/master | 2021-01-20T02:49:31.281036 | 2015-03-10T20:59:32 | 2015-03-10T20:59:32 | 26,771,078 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 852 | cpp | #include <vector>
#include <deque>
#include <iostream>
#include <stdexcept>
using namespace std;
template <class C>
void print (const C & container)
{
for(unsigned i = 0; i < container.size(); ++i)
{
cout<< container.at(i) << " ";
}
cout<<endl;
}
int main()
{
int a[] = {1,2,3,4,5,6,7,8,9,10};
//containers
... | [
"lester.crespo.es@gmail.com"
] | lester.crespo.es@gmail.com |
c5b9fe4d97e3508396184952d52f5bc13b608faf | ab4d0a025300f2237e1a389a27772fcc8c8e9e75 | /A1/part-5/Project1/Project1/Hand.h | f743ec2b431178a39d39759b0c949882df2662bb | [] | no_license | SunXP/Risk-Game | 8aee3481aa025a3891d3274ca6d017e870326436 | 11ba5597e3a809f672bc865f60c611a59c638ccd | refs/heads/master | 2021-10-04T08:12:22.232433 | 2018-12-03T16:33:43 | 2018-12-03T16:33:43 | 148,411,540 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 393 | h | #pragma once
#include <vector>
#include "Card.h"
#include "Deck.h"
using namespace std;
class Deck;
class Hand
{
public:
Hand();
~Hand();
int exchange(Deck&);
void exchange3Cards(Deck&, string);
void exchangeDifferentCards(Deck&);
int calculateExchangedArmySize();
void addCardToHand(Card*);
vector<Card*>& ge... | [
"roger_lu_dude@hotmail.com"
] | roger_lu_dude@hotmail.com |
5538d11ce902cd68d72c45ceff82a0a121c66992 | 8498f7223cb84b20dbb402e8daee43df266c6443 | /practice/杭电/杭电2066dijkstra.cpp | 5dd61e41a52fb88811aaf775da4908509d773e95 | [] | no_license | CRblog/algorithm | 201afa4c0f1886f9a43db68d906bb2e30766d044 | 824d6d8a08d7ff3304f87e3376722414aebdeffc | refs/heads/master | 2020-04-13T01:02:42.336150 | 2019-09-23T02:37:35 | 2019-09-23T02:37:35 | 162,862,258 | 0 | 0 | null | null | null | null | GB18030 | C++ | false | false | 1,994 | cpp | #include<iostream>
#include<cstdio>
#include<string.h>
#include<algorithm>
using namespace std;
const int Max = 9999999;
int dis[1002][1002],vis[1002],d[1002],n,m,flag;
void djs()
{
for( int i = 0; i <= n; i ++)
d[i]=dis[0][i];//保存到每个城市的距离
for( int j = 1; j <= n; j++)
{
m=Max;
for(in... | [
"1422423453@qq.com"
] | 1422423453@qq.com |
79f1e514bb636dd49c18283d4d4c37cdb28feb7c | 7af9c24bb6cea6e77c74990fbdf061bd03c0e779 | /src/Out.cpp | 56d8cb5589a7ab874465e1fd93c674ccc144796f | [] | no_license | dtbinh/sedgewick_cpp | abfca17d774f03cfde912fe5404770fad68a8628 | b488e5df2ad9c855aaaed66397c457dba55a4463 | refs/heads/master | 2023-03-16T09:11:31.240153 | 2017-08-23T23:39:20 | 2017-08-23T23:39:20 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,465 | cpp | #include <sys/socket.h>
#include <ios>
#include "Out.h"
Out::Out(std::ostream& os)
{
try {
OutputStreamWriter osw = new OutputStreamWriter(os, CHARSet_NAME);
out = new PrintWriter(osw, true);
} catch (IOException e) {
e.printStackTrace();
}
}
Out::Out()
{
this(System.out);
}
O... | [
"timothyshull@gmail.com"
] | timothyshull@gmail.com |
fe4553bd7fb3c65431cffe8dcd621d0184f02316 | 80a5d9a29659eec123505273a4f0ef877bda6719 | /lab4/evshield_examples/mechbot_BEEP/mechbot_BEEP.ino | 83b25ffa37686cad1fcbce3b1d7b9d987aabd1ed | [] | no_license | alisaleemh/sys-design | dcfdaa4c4c0d013c9aa704b7d47fb354552f2206 | 639e0646d60aa36f4d5c832f66dde4b4c36b4909 | refs/heads/master | 2021-08-19T10:55:25.319291 | 2017-11-26T00:54:38 | 2017-11-26T00:54:38 | 103,178,010 | 0 | 0 | null | 2017-11-18T02:30:42 | 2017-09-11T19:21:07 | C++ | UTF-8 | C++ | false | false | 744 | ino | //manually beep the buzzer on PB3, and use beep command
#include <mechbotShield.h>
#include <avr/io.h>
#include <util/delay.h>
int main (void) {
//set the data direction registers B and D hi (output)
DDRB |= (1 << PB0) | (1 << PB1)| (1 << PB3) | (1 << PB4) | (1 << PB5);
DDRD |= (1 << PD6) | (1 << PD7);
init... | [
"ahussain@ca.ibm.com"
] | ahussain@ca.ibm.com |
141485e8fc313d62d07a5a055f1e5a3fa8d2d591 | b1ac06d8b80d3dd846735385453acc0b271568c2 | /hack/async_udp_echo_server.cpp | be4ef2d688bc1b473c6cab63e57b06095fd5aecd | [] | no_license | spk121/udptoserial | e0440a386a4e363c1cd3fadef3c66be987473edf | 10e3c18be223026f77537b68f832e4a916ae276e | refs/heads/master | 2021-08-28T15:22:26.388240 | 2017-12-12T15:48:03 | 2017-12-12T15:48:03 | 110,750,178 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,718 | cpp | //
// async_udp_echo_server.cpp
// ~~~~~~~~~~~~~~~~~~~~~~~~~
//
// Copyright (c) 2003-2015 Christopher M. Kohlhoff (chris at kohlhoff dot com)
//
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
//
#include <sdkddkve... | [
"spk121@yahoo.com"
] | spk121@yahoo.com |
80ba20d3ce9da24efb30b7adedbe28855fd2a487 | 0811473df9f1fc541e0c430b9eae4ebf5e7634a5 | /include/callable_traits/detail/sfinae_errors.hpp | 0679534f9e8d818971d8326dd6b2808487638d30 | [
"BSL-1.0",
"LicenseRef-scancode-unknown-license-reference"
] | permissive | Hincoin/callable_traits | ff6a90b1fad12b439cb0beb78277e1d88ac9794c | 128e18ded8d354f4eb64963cdfd0c40800cf4b50 | refs/heads/master | 2021-01-18T13:45:06.638589 | 2016-06-30T21:22:48 | 2016-06-30T21:22:48 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 4,243 | hpp | /*!
@copyright Barrett Adair 2016
Distributed under the Boost Software License, Version 1.0.
(See accompanying file LICENSE.md or copy at http://boost.org/LICENSE_1_0.txt)
*/
#ifndef CALLABLE_TRAITS_SFINAE_ERRORS_HPP
#define CALLABLE_TRAITS_SFINAE_ERRORS_HPP
#include <callable_traits/config.hpp>
#include <type_trai... | [
"badair@harding.edu"
] | badair@harding.edu |
464bd52050c4a1bdeda95ca2682cbf365fe2271b | ddb75a799dfeed497661f7c4051b2ad2c1ee4010 | /examples/PCF85063TP_Real-Time_Clock_Calendar/PCF85063TP_Real-Time_Clock_Calendar.ino | 8032a7fc0d1aedf5bfd3a450e2f3c602d82dd719 | [
"Unlicense"
] | permissive | Globaltronic/discover32 | 8058b65448091e7f4f7ac1fc147886fa7c67b77e | 8eaa3d686e4190f9f0c3e561ab6f2f77681000e6 | refs/heads/master | 2023-02-01T00:04:12.835876 | 2020-12-18T11:35:16 | 2020-12-18T11:35:16 | 304,587,552 | 4 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 1,285 | ino | #include <Wire.h>
#include <PCF85063TP.h>
#define I2C_SDA 21
#define I2C_SCL 22
PCD85063TP RTclock;
void setup(void) {
Wire.begin(I2C_SDA, I2C_SCL);
Serial.begin(115200);
Serial.println("PCF85063TP Real-Time Clock Calendar test");
RTclock.begin();
/* Set a specific time and date. */
RTclock.stopCloc... | [
"ficacador@gmail.com"
] | ficacador@gmail.com |
249a0a05ddbcf08c8718bdedb65cba1c3982d9a1 | 376b0398da6d9886762b940a33aab29e0ebd9990 | /CSES/TreeAlgorithms/tree_matching.cpp | 069011d6f6e51190522c01ca24ddf807986360ac | [
"MIT"
] | permissive | PranavReddyP16/CP-Utils | 6069b089dae74c9be2500b600a4757f3506b68a5 | cb68b1ced5fd4990a413ce88cdb741fdcaa6e89b | refs/heads/master | 2023-06-30T13:11:39.224751 | 2021-08-05T18:54:40 | 2021-08-05T18:54:40 | 297,747,230 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,960 | cpp | #include "bits/stdc++.h"
#include <ext/pb_ds/assoc_container.hpp>
#include <ext/pb_ds/tree_policy.hpp>
using namespace __gnu_pbds;
using namespace std;
using namespace std::chrono;
#define ll long long
#define ld long double
#define sz(c) ((ll)c.size())
#define ordered_set tree<int, null_type,less<int>, rb_tree_tag,t... | [
"bestpranav.16@gmail.com"
] | bestpranav.16@gmail.com |
e3b33036046a08cf74dbbb2741881877124d3152 | 5a47eee378d38318ecd1c5946ca18dcbb1bc4e5d | /Bulls and Cows/Bulls and Cows.cpp | a2a7b0e97193c3c3255d49f0a3be24ac1fc44d49 | [] | no_license | Nesi01/Bulls_and_Cows | 1b344cb839688d6dd830cbb22f6e4328d560d741 | 6af4effce8dbf524e5a9cc0b9640c33337e36872 | refs/heads/main | 2023-02-05T19:36:27.593134 | 2020-12-26T20:23:05 | 2020-12-26T20:23:05 | 324,045,089 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,311 | cpp | #include "Player.h"
using namespace std;
void BullsAndCows();
int main()
{
setlocale(LC_ALL, "Russian");
string main;
do
{
cout << "БЫКИ И КОРОВЫ\n";
cout << "[1] - Новая игра.\n";
cout << "[2] - Выход.\n";
getline(cin, main);
if ((main == "1")||(main=="star... | [
"valerawow01@mail.ru"
] | valerawow01@mail.ru |
53fc55394a14a34054b8984eeafbd0d72a6ce731 | 0507d05ecc8aae0f8ce65eae5de44d74fc24058f | /libosdp_pd.ino | 72b055a5835da1e38d40c8c03f543a8ded6ccb3e | [] | no_license | vk2tds/libosdp_pd | 83a0a61b5137e8fa6d6386881b7705c18703c0bf | a39821a2d1032c0eb45098be28640cf0e9db3c21 | refs/heads/main | 2023-08-18T17:32:37.997649 | 2021-10-11T06:43:37 | 2021-10-11T06:43:37 | 413,724,874 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 5,417 | ino | /*
* Copyright (c) 2021-2021 Siddharth Chandrasekaran <sidcha.dev@gmail.com>
*
* SPDX-License-Identifier: Apache-2.0
*/
#define OSDP_EXPORT
#define OSDP_NO_EXPORT
#define CONFIG_OSDP_PACKET_TRACE TRUE
//#include <iostream>
#include <unistd.h>
#include <osdp.hpp>
//HardwareSerial debugSerial = Serial; // (PA3,... | [
"darryl@radio-active.net.au"
] | darryl@radio-active.net.au |
19d23d7331caff8277b4499f59f7bcf72e5fa739 | c6db34b95130785279406c8635d4907a6748f4f9 | /Purple/Purple/MemoryArena.h | 73b42e9f244873f5be6ed0e6fbb7acb3d0a5e0ec | [] | no_license | hustruan/Queen | de2424896573ea72556f1b9b420a468e4d643d43 | ec3a5b8289c0c29b807fea5388ae09c695d59702 | refs/heads/master | 2016-09-01T21:10:49.987029 | 2014-08-07T07:02:38 | 2014-08-07T07:02:38 | 8,200,583 | 1 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 1,782 | h | #ifndef MemoryArena_h__
#define MemoryArena_h__
#include "aligned_allocator.h"
#include <vector>
#include <cstdint>
#include <algorithm>
namespace Purple {
using RxLib::aligned_malloc;
using RxLib::aligned_free;
class MemoryArena {
public:
// MemoryArena Public Methods
MemoryArena(uint32_t bs = 32768) {
blockSi... | [
"ruanmengkai@gmail.com"
] | ruanmengkai@gmail.com |
7eebb5370bac26d846f889729d0f1cb6e343c5c3 | b84aa8a1745f3346f22b9a0ae1c977a244dfb3cd | /SDK/RC_WBP_PlayerCustomizeScreen_parameters.hpp | db41eea8584de49dd53f48ea9b7a543c4d1f71f7 | [] | no_license | frankie-11/Rogue-SDK-11.8 | 615a9e51f280a504bb60a4cbddb8dfc4de6239d8 | 20becc4b2fff71cfec160fb7f2ee3a9203031d09 | refs/heads/master | 2023-01-10T06:00:59.427605 | 2020-11-08T16:13:01 | 2020-11-08T16:13:01 | 311,102,184 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 851 | hpp | #pragma once
// RogueCompany (4.24) SDK
#ifdef _MSC_VER
#pragma pack(push, 0x8)
#endif
#include "../SDK.hpp"
namespace SDK
{
//---------------------------------------------------------------------------
//Parameters
//---------------------------------------------------------------------------
// Function WBP_Play... | [
"60810131+frankie-11@users.noreply.github.com"
] | 60810131+frankie-11@users.noreply.github.com |
67d6b0f8547f954c139cc1424871a037406592d5 | ec088ff3a34376defe194132fb2207e3b4798628 | /problems/938A/938A.cpp | 8ee45070f797ad5ddff9eb7c08856101dc019895 | [] | no_license | radpet/algo | ee0a57b3ff9305659ca7634c9e9cbbb9accbab49 | 7bdcdd56b26107d5aae928fffdb5dbc619613a09 | refs/heads/master | 2022-07-10T19:24:35.520151 | 2019-12-23T17:47:18 | 2019-12-23T17:47:18 | 71,000,261 | 0 | 0 | null | 2022-06-21T23:35:33 | 2016-10-15T16:40:32 | C++ | UTF-8 | C++ | false | false | 508 | cpp | #include<iostream>
using namespace std;
bool isV(char c) {
return c == 'a' || c == 'e' || c == 'i' || c == 'o' || c == 'u' || c == 'y';
}
int main() {
int n;
cin >> n;
char lastCh;
for (int i = 0; i < n; i++) {
char ch;
cin >> ch;
if (i != 0) {
if (isV(lastCh) ... | [
"radipirate@gmail.com"
] | radipirate@gmail.com |
4ee38215d28e6846e8bfca4042afb99c75909e09 | 0b5688fd9bda4f2513aaac9e57b30ca318763e17 | /ChainOfResponsibilityPattern/dialog.h | a423b77d08a4628f4007f1cb656e3e1a0540636a | [] | no_license | saranfly/DesignPatterns | 230fe36df7c908626254fff7d04c10c439c439ff | 3dab3c0ff5292474ec3e244d6164e572dfc7ee11 | refs/heads/master | 2021-01-01T04:19:34.066682 | 2017-09-12T15:16:00 | 2017-09-12T15:16:00 | 57,225,378 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 267 | h | #ifndef DIALOG_H
#define DIALOG_H
#include "widget.h"
class Dialog : public Widget
{
public:
Dialog(Widget* w = NULL, Topic t = NO_HELP_TOPIC);
virtual void HandleHelp();
//Widget operations that Dialog overrides...
~Dialog();
};
#endif // DIALOG_H
| [
"yangbenjob@sina.com"
] | yangbenjob@sina.com |
fbc65e952b0124e6e06d9726f901aaeb1fb5007f | fcaf92c2169d962debe95b88391389ce5a73dc8d | /src/common/communication/udp/UdpSender.h | 813f6620f401775eb47e7bcebf8738cfcaf7f46b | [] | no_license | erostamas/brewer | 4517ee5522d580a2287408875205b034d39ba223 | e387b82797138626082e8709ee377b7f85ed1c56 | refs/heads/master | 2021-01-17T02:22:57.884045 | 2018-05-18T18:49:14 | 2018-05-18T18:49:14 | 53,972,136 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 524 | h | #pragma once
#include <boost/asio.hpp>
#include <string>
#include <memory>
class UdpSender {
void init();
public:
UdpSender(const std::string& ipAddress, unsigned port);
UdpSender(boost::asio::ip::udp::endpoint remoteEndpoint);
~UdpSender();
void send(const char* message, std::size_t length);
... | [
"tamas.eros1@gmail.com"
] | tamas.eros1@gmail.com |
19ac0fd6846882e993fe6137846df7ce886a37ad | 1918829b482d834c3014c59f4e8003dc9863ee9a | /CPP01/ex03/ZombieHorde.cpp | 3ff4ad6a144b09b28d9e24150a29db24893d9697 | [] | no_license | hollyhox-21/CPP_moduls | 655ef38c6d1d4781e68593453d1cad6a34e2d80a | eef9efd1eb3db10191ba8574eba740abdf9ee662 | refs/heads/master | 2023-04-16T07:38:56.514404 | 2021-05-04T16:14:36 | 2021-05-04T16:14:36 | 352,750,599 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 982 | cpp | //
// Created by Retro Joella on 3/31/21.
//
#include "ZombieHorde.hpp"
#include "Zombie.hpp"
#include <string>
ZombieHorde::ZombieHorde(int countZombie) : _sizeHorde(countZombie){
_zombieHorde = new Zombie[_sizeHorde];
for (int i = 0; i < _sizeHorde; ++i) {
setZombieName(_zombieHorde[i]);
setZombieType(_zombie... | [
"rjoella@ge-n2.kzn.21-school.ru"
] | rjoella@ge-n2.kzn.21-school.ru |
edc130e65824f4863516991204027845ae6414b2 | 46d8761f5ebcc227b0327a93e032ac3a6c20b33e | /src/net.cpp | 92a9dd10ba3437b52787eb30dcbace735e779c14 | [
"MIT"
] | permissive | ccdevplus/Piron | cdac13b1d83296754429c12836da955b7a7c90f4 | be20c264030a4f1ef904ae13c79eaec474aaa5ec | refs/heads/master | 2020-07-05T04:31:18.027693 | 2016-11-18T12:54:45 | 2016-11-18T12:54:45 | 74,118,172 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 55,146 | cpp | // Copyright (c) 2009-2010 Satoshi Nakamoto
// Copyright (c) 2009-2012 The Piron developers
// Distributed under the MIT/X11 software license, see the accompanying
// file COPYING or http://www.opensource.org/licenses/mit-license.php.
#include "chainparams.h"
#include "db.h"
#include "net.h"
#include "core.h"
#include... | [
"qunity3d@yandex.ru"
] | qunity3d@yandex.ru |
9f873b9eaa660db588741c1711206beb5547cca7 | 55a1b57c22c8b8be7f0dd2c863303a73ba141e10 | /lab7/ArraySum/ArraySum/ArraySum.cpp | 5a3367cf7f726a42d2514decc91a4ffad3ec8489 | [] | no_license | igor-dev13/oop | 61be17bf17951920d2f8f97599b5d34924453749 | 02fc17dc79a8960f7c602a2145f55e554b7a820c | refs/heads/master | 2020-04-05T22:55:51.795986 | 2017-01-27T21:56:17 | 2017-01-27T21:56:17 | 68,246,347 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 92 | cpp | #include "stdafx.h"
#include "ArraySum.h"
using namespace std;
int main()
{
return 0;
}
| [
"igor_xp@mail.ru"
] | igor_xp@mail.ru |
6371c449e3e455872fbabd094a07fb940801f7df | 32bc210363566fb734c7ed5b000d672614310b98 | /nrf905_serial_bridge_rx/init.cpp | e4ff0f3acbbe84cb380e669bf317b1f7925b013c | [
"MIT"
] | permissive | koson/stm32f030 | a19b0fea545aba27adeff55ca00e44d6243f8ac5 | bc6d9a5dfb2e7346893f012fa7fb494bbb46a555 | refs/heads/master | 2022-07-22T23:10:38.424832 | 2020-05-21T07:36:03 | 2020-05-21T07:36:03 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 32 | cpp | ../nrf905_serial_bridge/init.cpp | [
"frank.duignan@gmail.com"
] | frank.duignan@gmail.com |
a786a7ca6c2bdeffe31e4eaba99677e0797ecc0c | 907ea3522c4ec3c13a758c97e737bdb15c4b8760 | /ssvlab/benchLuiz/benchmarksGklee/106_fail/main.cpp | 6be9b05acdc5963744538e8a5a351142ca3f9093 | [] | no_license | LuizHenriqueSena/testesDiversos | 1001b1a28963ae1cabff88763116f15bda5701ea | c6095148a4c2171451336c6525d328af603f7c4b | refs/heads/master | 2021-06-15T20:16:45.538413 | 2021-02-19T15:20:55 | 2021-02-19T15:20:55 | 148,709,926 | 1 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 775 | cpp | #include <cuda.h>
#include <cuda_runtime_api.h>
#include <stdio.h>
#include <assert.h>
#define N 2
__device__ double C[2][2][2];
__device__ int index (int a, int b, int c){
return 4*a + 2*b + c;
}
__global__ void foo(double *H) {
int idx = index (threadIdx.x,threadIdx.y,threadIdx.z);
H[idx] = C[threadIdx.x]... | [
"coelho.luiz.sena@gmail.com"
] | coelho.luiz.sena@gmail.com |
86991d1d358a0ce650e7817d1866bcb8af3f74c4 | 1e9ed78a4f3ed241642de75040a7b71411df62e4 | /soccer/KickEvaluatorTest.cpp | f6a6945bdbf5a6408fae0b07a4c8a75f8d515208 | [
"Apache-2.0"
] | permissive | acpollmann/robocup-software | 5c8ec71e8dd1c7dda3b2900fb99613d00aad26f0 | eea70078a6b48b986649db00ddfb62605c70b1b7 | refs/heads/master | 2021-05-05T05:50:39.651219 | 2018-01-21T19:46:56 | 2018-01-21T19:46:56 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,441 | cpp | #include <gtest/gtest.h>
#include "KickEvaluator.hpp"
#include "SystemState.hpp"
#include <stdlib.h>
using namespace Geometry2d;
TEST(KickEvaluator, no_robots) {
SystemState state;
KickEvaluator kickEval(&state);
std::pair<Point, double> pt_to_our_goal;
std::pair<Point, double> expected =
std... | [
"fcdneiger@gmail.com"
] | fcdneiger@gmail.com |
2baf38cd91e61421145734c836f322aa047c9955 | efd6a4614311501359602ab0a35fb3aeef6af4a4 | /src/GameLibrary/Application/ApplicationData.cpp | ffd1544b2a1b72a31be8e85ca71b2312e43034c7 | [] | no_license | Joewessel27/MobileBrawler | 129eee742ec79edf148d824e2224467148dec32c | 4cd7bf3b3d5d01d5f1ea3587a2fc5179929224f1 | refs/heads/master | 2021-05-31T16:43:53.605681 | 2016-02-28T17:46:15 | 2016-02-28T17:46:15 | 55,022,134 | 2 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,054 | cpp |
#include "ApplicationData.h"
#include "Application.h"
namespace GameLibrary
{
ApplicationData::ApplicationData(Application*app, Window*win, AssetManager*assetMgr, const TimeInterval&time, const TransformD&transfrm, double fpsMult)
{
application = app;
window = win;
assetManager = assetMgr;
timeInterval = ti... | [
"luisfinke@gmail.com"
] | luisfinke@gmail.com |
aec112f1195eca593a5f4dc9a425981aff3bf9e0 | 5fde4bdbc97e04ffb69a670ee89f5764b7338970 | /test-src/test1.cpp | 20b76be59c28d1b9ad620bb9fdd61d0b3c9b81e0 | [] | no_license | ImBest2016/LinuStuff | 0cbf0d3a22b6cd12a0fe2338a1811141adb89df5 | 77a140c569d35ffb162b87237ccfb0d05812d820 | refs/heads/master | 2021-01-10T16:29:43.352053 | 2015-12-29T01:12:35 | 2015-12-29T01:12:35 | 48,597,133 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 6,993 | cpp | /*************************************************************************************
*
* VERY VERY IMPORTANT
*
* --- prequest : ---
* 1. before you do this test, you must install two libraries and develop libraries
* libparted, libuuid and libparted-devel, libuuid-devel
* 2. you must install the command h... | [
"imbest2016@sina.cn"
] | imbest2016@sina.cn |
975a0b9d07a6efc100405f0991d2f373047823a2 | f393e8ea54685ae881e5c71331ffc4625735ac2e | /hikr/build/Android/Preview/app/src/main/include/Outracks.Simulator.Pr-81de9449.h | 787f25441d372386555f9bcd84560f45e99b11ad | [] | no_license | joseph-shumway/Manna | f4c92f56152d3d206f8c9b1e9392a11d6245f10c | 13354425ee59b10f3c22bbc442fdd85db2aa9d17 | refs/heads/master | 2022-02-17T01:20:42.479275 | 2017-12-21T23:23:47 | 2017-12-21T23:23:47 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,660 | h | // This file was generated based on C:/Users/Shumcom/AppData/Local/Fusetools/Packages/Outracks.Simulator.Common.Uno/0.0.0/Messages/Diagnostic.cs.
// WARNING: Changes might be lost if you edit this file directly.
#pragma once
#include <Outracks.IBinaryMessage.h>
#include <Uno.Object.h>
namespace g{namespace Outracks{na... | [
"thegreenjag1@gmail.com"
] | thegreenjag1@gmail.com |
dd68a55e133275810172b8bec91a321c9236f9d6 | afe94d3675f1d4ad2274cfd5f9eab0f378877bf1 | /lesson_09/03_QThreads_QMutex/incthread.h | fc23c66668881a776aa9f0ceee9fa796d9921f78 | [] | no_license | Chuvi-w/cpp | d807f51fcc9431997dbe97244b4ebf5c177e3258 | be3066bfa4844f4bc08bac981f51f3ce628a4f2a | refs/heads/master | 2021-01-17T21:39:26.340626 | 2015-08-29T10:47:13 | 2015-08-29T10:47:13 | 42,061,059 | 1 | 0 | null | 2015-09-07T15:38:46 | 2015-09-07T15:38:45 | null | UTF-8 | C++ | false | false | 159 | h | #ifndef INCTHREAD_H
#define INCTHREAD_H
#include <QThread>
class IncThread : public QThread {
Q_OBJECT
protected:
void run();
};
#endif // INCTHREAD_H
| [
"super.denis@gmail.com"
] | super.denis@gmail.com |
4f0c9bcc934e59d634755d0c13d5480141933242 | 083ad051981273866006eb777311ba486a06e214 | /lib/libjamsat/concepts/ClauseTraits.h | fa7baa4597f64f4b62a05bdab41dd762544a9be5 | [
"MIT",
"X11"
] | permissive | fkutzner/JamSAT | 31d0932f1f0acf7fa63bc86cad83e5fe031fc03b | 226a8b3ba79a5450e96bd4b98015e1f6a187d290 | refs/heads/master | 2021-05-23T05:48:20.160881 | 2020-08-23T11:30:57 | 2020-08-23T11:30:57 | 94,918,870 | 7 | 1 | null | 2018-05-20T19:30:33 | 2017-06-20T17:43:04 | C++ | UTF-8 | C++ | false | false | 19,638 | h | /* Copyright (c) 2018 Felix Kutzner (github.com/fkutzner)
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, mer... | [
"felixkutzner@gmail.com"
] | felixkutzner@gmail.com |
f0157baaa47039abd7acdcc01ff9b688f9f8be34 | 5447a87c9fa3cd790453a8bf4a40761b4fbb099b | /leetcode2/CTCI/CTCI_15.cpp | 67e049dfcf1a9b7e44647eb78bfdcc396bb91497 | [] | no_license | necromaner/C- | ffb215520d3035a1e785147303c753a10a47619a | f7978b358f8246072c7f9627cee80e5df1994b25 | refs/heads/master | 2021-05-25T09:13:32.011117 | 2020-11-10T09:00:47 | 2020-11-10T09:00:47 | 126,946,399 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 18 | cpp | #include "CTCI.h"
| [
"necromaner@foxmail.com"
] | necromaner@foxmail.com |
a14a01ad12fb2e55b4796aedc92b96a2d57241fd | a34a62fbdc7aedf2dac1cbba7752032a081df84c | /include/cyvm/TypeClass.hpp | 0b337c04670916a02372890e5f234014530fdf3e | [] | no_license | cybrown/CyLang | 25b44171ae8ab3ff757357d111efa88ab8d48aba | dc517c97942edaeffe56d4529987798170aa27f6 | refs/heads/master | 2021-01-19T08:48:46.421170 | 2012-11-20T03:13:30 | 2012-11-20T03:13:30 | 6,771,353 | 0 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 618 | hpp | #ifndef __TYPE_CLASS__
#define __TYPE_CLASS__
#include "Type.hpp"
#include "Class.hpp"
#include <vector>
/**
Class for a type containing a class.
It can handle template classes, with a list of parameters.
*/
class TypeClass: public Type {
protected:
Class *type_class;
std::vector<Type*> parameters;
bool _... | [
"cy@cybrown.fr"
] | cy@cybrown.fr |
201d74130d15be7da1dbc11ede824484b3d2ccf5 | c047518e0bc0be1d1a46b734fbf53610cb8a407f | /Codeforces/1245/C.cpp | 05db0594fd3d0efce6a8b728ecf35baa493bba57 | [] | no_license | fernandozanutto/competitive_programming | c3e006544ddba1702a37eeb437cb015713e8c2d1 | cf721a7bcce6c5d5fc9f739ad729079c939fc421 | refs/heads/master | 2020-06-19T06:57:32.288602 | 2020-04-04T14:58:45 | 2020-04-04T14:58:45 | 196,607,123 | 2 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,391 | cpp | #include <bits/stdc++.h>
using namespace std;
const int MOD = 1e9+7;
int memo[100005];
int fact(int n){
return (n <= 1 ) ? 1 : ((fact(n-1) * n) % MOD);
}
int calc(int n){
//cout << "somatario, n="<< n << endl;
int res = 0;
for(int i=0; i <= n/2; i++){
res += fact(n-i) / ... | [
"ferzanutto1999@gmail.com"
] | ferzanutto1999@gmail.com |
ab94f700745c5ecf667f1123f50ca8a1a3a4c4fb | 506efa7eb7e68c4b2e211fc949d445e4736fc062 | /Raster-Images/src/reflect.cpp | cdd79217192b837cb3e6573b3495d4238115d89b | [] | no_license | willmorley/Computer-Graphics-Assignments | 910c4010f7a36c8d65bdf53d83601b64dc39a791 | 7c16809d4c3e4b4aaea3e00de28d9a4988e11f0b | refs/heads/master | 2021-11-23T19:37:41.969297 | 2021-11-20T22:57:24 | 2021-11-20T22:57:24 | 177,896,070 | 1 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 622 | cpp | #include "reflect.h"
void reflect(
const std::vector<unsigned char> & input,
const int width,
const int height,
const int num_channels,
std::vector<unsigned char> & reflected)
{
reflected.resize(width*height*num_channels);
auto end = (width * num_channels) - num_channels;
for(auto i = 0; i < height; i... | [
"will.morley@mail.utoronto.ca"
] | will.morley@mail.utoronto.ca |
18eb137dc8656c259d0fcc5de75218e6f5181043 | b28ee4aeb8a82798b1b85abb3676992bf6efbcaf | /TeamProject/Classes/Room/GameRoom.cpp | c85b45ed47977514a2dea7fc8318eb9625d065ac | [] | no_license | leduyvu/RacerMouse | 4dbbf131defc276ed46fff40b9e692857785d163 | a6a1f62c241ed0277c26c30e22824634ff76a550 | refs/heads/master | 2021-01-19T14:33:43.763525 | 2014-03-28T11:43:51 | 2014-03-28T11:43:51 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,699 | cpp |
#include "GameRoom.h"
#include <pthread.h>
CCScene* GameRoom::scene(Client* client){
CCScene *scene = CCScene::create();
GameRoom *layer = GameRoom::create(client);
scene->addChild(layer);
return scene;
}
GameRoom::GameRoom(){
}
GameRoom* GameRoom::create(Client* client){
GameRoom* pRet = new Ga... | [
"le.duy.vu@framgia.com"
] | le.duy.vu@framgia.com |
84f430faaee26c67f918eb9d5c9fe0c264e6de3d | f1609032d1293f05ca29a4f741d8bfa1f3119679 | /Applications of NT-1/Advanced_GCD.cpp | bf7a0954fc133a6aac1df1f139664664e182ac5e | [] | no_license | Bhagesh-Bhutani/Competitive-Programming | 82bea49fd7af6cf662c882b8f85479e919bcf08f | 8007ae0e08ddecbcab98fa49d86c7e3e64df1b9e | refs/heads/master | 2023-01-04T23:12:13.445862 | 2020-11-04T13:17:48 | 2020-11-04T13:17:48 | 289,540,934 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 436 | cpp | #include<bits/stdc++.h>
#define ll long long int
using namespace std;
ll gcd(ll a,ll b){
if(b==0){
return a;
}
return gcd(b,a%b);
}
int main(){
int t;
cin>>t;
while(t>0){
ll a;
string b;
cin>>a>>b;
ll mod=0;
for(int i=0;i<b.length();i++){
... | [
"bhutanibhagesh49@gmail.com"
] | bhutanibhagesh49@gmail.com |
b3d8ecb795d113b606b41a7387b50a9c837bea2a | ce161c98d5b1a69fd12b7af691709a76da55b44d | /codeforces/VK_Cup_2012_Round_3_(Unofficial_Div_2_Edition)/A_Problem_About_Equation.cpp | 7ddf85ba3c7a0047bb19a546e8e5c835b03453e0 | [] | no_license | cup2of2tea/CompetitiveProgramming | cb45d40ff0c27e2b9891eb135e4e5ef795014989 | eaa9bfac351c0eb909c7686534fe647c31eaac65 | refs/heads/master | 2020-09-02T07:21:18.722266 | 2019-11-02T14:30:57 | 2019-11-02T14:30:57 | 219,165,630 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 671 | cpp | #include <iostream>
#include <vector>
#include <iomanip>
using namespace std;
int main()
{
int n;
double b;
cin>>n>>b;
double avg;
vector<double> res(n);
vector<double> v(n);
for(int c=0;c<n;c++)
{
cin>>v[c];
b+=v[c];
... | [
"comtealexis@gmail.com"
] | comtealexis@gmail.com |
717db58946653896ae1aa67cf2b1c9bfd9c5ed76 | d104057b11051851252a100afa1d9b155d807ff2 | /src/lvio_fusion/src/local_map.cpp | bf5caa6e9cb959052ebc8729ad4212d8d97c3358 | [] | no_license | TurtleZhong/lvio_fusion | 39f41e2d05d1c2a95168e0507b7833ece42d0a4d | 829ba5d446c41ff166f7cf090aeb930cf70ae27a | refs/heads/main | 2023-06-06T00:32:34.082334 | 2021-06-28T02:58:20 | 2021-06-28T02:58:20 | 388,458,640 | 2 | 1 | null | 2021-07-22T12:43:47 | 2021-07-22T12:43:47 | null | UTF-8 | C++ | false | false | 13,360 | cpp | #include "lvio_fusion/visual/local_map.h"
#include "lvio_fusion/ceres/visual_error.hpp"
#include "lvio_fusion/map.h"
#include "lvio_fusion/utility.h"
#include "lvio_fusion/visual/camera.h"
namespace lvio_fusion
{
inline cv::Mat brief2mat(BRIEF &brief)
{
return cv::Mat(1, 32, CV_8U, reinterpret_cast<uchar *>(&brie... | [
"jypjypjypjyp@hotmail.com"
] | jypjypjypjyp@hotmail.com |
a768764b84470cba6cb0aa12fc2bb0b657c69c3e | c6ddd1f399be41154f99999433d9e56b48b891e3 | /main.cpp | ae2e8be4ef5e2181f7b2a1300d3e13801ccc14f2 | [] | no_license | panduhbyte/ls4 | 26a81744f4c2d362ae8eee66be9fa2e129ecba61 | 62e3a73bf49ba19d1d5c9811e5e6f82d785e2744 | refs/heads/master | 2021-08-06T18:26:27.650910 | 2017-11-06T18:38:23 | 2017-11-06T18:38:23 | 109,734,741 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,271 | cpp | #include <iostream>
#include <vector>
#include <list>
using namespace std;
/*
* Create a vector and list of integers (vector<int> , list<int>). Use at least 20 elements.
* Fill them with randomly generated numbers wthin a range (use iterators on the containers)
* Sort the vector and list - using std::sort(v.beg... | [
"panduhbyte@gmail.com"
] | panduhbyte@gmail.com |
26da1f4778997e5235dc7f4563c8f3e7d0dc6a92 | af0aa93c55cbf9fcd8589cd0f764f9c348db8c9f | /Engine/Scenarios/scenariointerface.hpp | 0f04bc53c629492f95c49c3c33c8ab62b924070b | [] | no_license | Kickass-Global/Checkered | c758ad2ebd963fc8b07949c58e5f225eb486de06 | 399e1e666a16b4b35740ae6c46f339f9c7514b67 | refs/heads/master | 2020-12-06T07:03:43.419680 | 2020-04-20T17:29:45 | 2020-04-20T17:29:45 | 232,375,415 | 5 | 1 | null | 2020-04-20T16:27:50 | 2020-01-07T17:11:52 | C++ | UTF-8 | C++ | false | false | 526 | hpp | //
// Created by Jackson Cougar Wiebe on 3/13/2020.
//
#ifndef ENGINE_SCENARIOINTERFACE_HPP
#define ENGINE_SCENARIOINTERFACE_HPP
namespace Engine {
class ScenarioInterface {
protected:
friend class EngineSystem;
EngineSystem* enginePtr;
public:
explicit ScenarioInterface(EngineSystem* enginePtr) : enginePtr... | [
"jacksoncougar@gmail.com"
] | jacksoncougar@gmail.com |
332da8f7adbf34cca21e40740dede00c64638cae | 720e26bd971a52598cf2cc32cf681c055825fe49 | /Lab 10a/Student_Code/Fighters.h | 9cc62e8dee77bcfb45d2d1332b27c70e6c26f80a | [] | no_license | CaptBoscho/earlycsclasses | 57af422aa87db6490dab804716e7c755ce799db8 | e4798e187485cc8e390769a29738a3b3499e1edb | refs/heads/master | 2016-09-01T03:33:40.293129 | 2016-01-11T18:27:19 | 2016-01-11T18:27:19 | 49,444,942 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 5,034 | h | #pragma once
#include "FighterInterface.h"
class Fighters:public FighterInterface
{
public:
~Fighters(void);
Fighters(string newName, int newHP, int newStrength, int newSpeed, int newMagic);
/*
getName()
Returns the name of this fighter.
*/
string getName();
/*
getMaxHP()
... | [
"cbyers6@ta-7.cs.byu.edu"
] | cbyers6@ta-7.cs.byu.edu |
1f1fbf2542aa7abe141f11a37b74f82e8c860bad | 525a8aec4ccfa9a72e7d6964d0f0b9ed3bc06025 | /src/EventHandler.h | de4d1a1458865eff1437bcb651c158be3ff968c6 | [
"ISC",
"BSD-4-Clause",
"BSD-2-Clause"
] | permissive | msargent/mdnsBro | 02dde5d0e4a3d570df7cb0889585c329f74ea452 | fa87a81a9649e5d8b1c19747fe23f551c84c6ea8 | refs/heads/master | 2021-01-10T21:13:34.954916 | 2011-01-21T00:32:10 | 2011-01-21T00:35:24 | 1,369,737 | 4 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,168 | h | // $Id: EventHandler.h 5911 2008-07-03 22:59:01Z vern $
//
// Capsulates local and remote event handlers.
#ifndef EVENTHANDLER
#define EVENTHANDLER
#include <assert.h>
#include "List.h"
#include "BroList.h"
#include "net_util.h"
class Func;
class FuncType;
class Serializer;
class SerialInfo;
class UnserialInfo;
cl... | [
"robin@icir.org"
] | robin@icir.org |
197d50933eab52d2c3ba4251c2671ac652b1edc9 | 98269fda17551dcdad69d25684179ff741d40535 | /cvm_follow_me_sample/src/FollowMeWindow.cpp | ea494e4ffeb4aa4d857e10492897c4319a259b08 | [] | no_license | Alibinwahid/viper-ros-samples | 054feba34d38319ffe9569a86ce7e31fb55f2728 | ebed68890fa38a29f526d89ddd78c98495307878 | refs/heads/master | 2020-04-23T13:49:28.859884 | 2019-03-18T10:32:30 | 2019-03-18T10:32:30 | 171,210,840 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 10,973 | cpp | /*******************************************************************************
* Copyright (c) 2018 by Rubedos
* Kaunas, Lithuania, www.rubedos.com
* All rights reserved.
*******************************************************************************/
#include "FollowMeWindow.h"
#include "ui_FollowMeWindow.h"
#inclu... | [
"alibinwahid@smme.edu.pk"
] | alibinwahid@smme.edu.pk |
a6a78a413130a3141524e39137d986da03f2a546 | 006aa66ee8da811e8117de7ef835c2ff243bdca3 | /ctci/dp/14Naive.cpp | 22cab305a7e4fdf3b8b7e11ad6f3cbe09961b06f | [] | no_license | 9915103227/CTCI-solution | 76367464c49d05070442df4b798754c6ee0470e0 | 18b4984b906505895ee2867ab67a8df779bfc0f5 | refs/heads/master | 2020-03-24T10:03:44.443317 | 2018-08-06T17:51:12 | 2018-08-06T17:51:12 | 142,646,080 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 2,776 | cpp | #include<bits/stdc++.h>
using namespace std;
int F(int *,char *,int,int);
int T(int *operand,char *op,int l,int r){
//cout<<"T "<<l<<" "<<r<<endl;
if(l==r){
return operand[l];
}
if(l==(r-1)){
if(op[l]=='&'){
if((operand[l]==1)&&(operand[r]==1))
{
//cout<<1<<endl;
return 1;
}
else{
//cout... | [
"psaxena130@gmail.com"
] | psaxena130@gmail.com |
fd4bf46f00b49a03baadd14e03c711743181daa5 | 0fe0ffe29ca6f76c6f15c85c8d82b09beaada246 | /net/quic/core/congestion_control/tcp_cubic_sender_bytes_test.cc | 28b4b954675ee477035cecdc983e55b1970a406c | [] | no_license | hanpfei/chromium-net | 4dc8fd48cf3b05d89b11dc121f9c3abdd3ba962e | 9df8ce98c2a14fb60c2f581853011e32eb4bed0f | refs/heads/master | 2023-07-08T15:28:01.033104 | 2023-06-14T13:02:39 | 2023-06-14T13:02:39 | 65,541,033 | 297 | 73 | null | 2022-11-02T23:33:48 | 2016-08-12T09:25:34 | C++ | UTF-8 | C++ | false | false | 35,498 | cc | // Copyright (c) 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "net/quic/core/congestion_control/tcp_cubic_sender_bytes.h"
#include <algorithm>
#include <cstdint>
#include <memory>
#include "base/loggin... | [
"hanpfei@gmail.com"
] | hanpfei@gmail.com |
a91f47b97a8881547744a5ab1f0ebb138c0ca3e9 | 8363c457a8a565431e5cdaedad40bfc83c1eebfa | /binary_search/rotatedSortedArray.cpp | e43401fc987cc1b3135f55698a2655a036297be9 | [] | no_license | apoorv-j/Data-Structures-Cpp | 968cd89d2cae38f0c8d2537683a584ce713dc2c2 | ba84fde6243fc9411eab80d0af12f6b6c57b77e3 | refs/heads/master | 2023-05-02T13:01:50.670719 | 2021-05-23T20:36:51 | 2021-05-23T20:36:51 | 268,308,122 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,362 | cpp | #include <bits/stdc++.h>
using namespace std;
int binary_search(int *arr, int n, int key)
{
int s = 0;
int e = n - 1;
while (s <= e)
{
int mid = (s + e) / 2;
if (arr[mid] == key)
return mid;
if (arr[s] <= arr[mid])
{
if (key >= arr[s] and key <= a... | [
"jainapoorv341@gmail.com"
] | jainapoorv341@gmail.com |
292df4817ed0f5f19254c13424a4df26cd311ecc | 78a244670f9c5d11d0d3af6d4e8352598c56c64c | /Project2/swapa.h | dfbb4cf230decbd2a3a63bf5cb8d0cee89238b11 | [] | no_license | Xu-Sir/Project2 | 34c7cdbd32aa20f7fd86cc72e70f4147ec585713 | aa7eaed80403dc188f8fc537023f81e39ffd4cfb | refs/heads/master | 2023-01-23T20:37:25.167633 | 2020-11-23T08:09:33 | 2020-11-23T08:09:33 | 303,663,184 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 81 | h | #pragma once
#include <iostream>
using namespace std;
void swap(int a, int b);
| [
"sss"
] | sss |
df4a7a6d5b8754c4870b0b989e94db8f2115a2c4 | e04048a59cce431e5200d5a722c96aafa07a4481 | /InLineHook/InLineHook/stdafx.cpp | c29bd261aaadd9dab5ae72f29e41091421fa726c | [] | no_license | liuxiao006/InLineHook | 168d24d64220db5a44648e16069079eecdc5d9be | 8170b0635dad9f0b33e909817537316255a9a885 | refs/heads/master | 2022-04-29T19:20:27.647909 | 2018-01-17T15:05:41 | 2018-01-17T15:05:41 | null | 0 | 0 | null | null | null | null | GB18030 | C++ | false | false | 269 | cpp | // stdafx.cpp : 只包括标准包含文件的源文件
// InLineHook.pch 将作为预编译头
// stdafx.obj 将包含预编译类型信息
#include "stdafx.h"
// TODO: 在 STDAFX.H 中引用任何所需的附加头文件,
//而不是在此文件中引用
| [
"root@DESKTOP-71O5AIH.localdomain"
] | root@DESKTOP-71O5AIH.localdomain |
054e575e47d6b3cf57817a3dd9b97a6fc01ee2fb | a41d1427492662093f699a092ac7ea2577dcbc9f | /arka.cpp | 8ed2b04e9b0fb58d4151c8b278740460e07ea1b2 | [] | no_license | SergioQV/Arkanoid | 1f409e1cb216b174b8d53bfa13b0e5ce8dbf7bb6 | c1a252106b0c67389461f14db2c98650c5ed91ac | refs/heads/master | 2020-10-01T05:26:15.014379 | 2019-12-11T22:00:40 | 2019-12-11T22:00:40 | 227,468,015 | 0 | 0 | null | null | null | null | ISO-8859-1 | C++ | false | false | 16,590 | cpp | #include <allegro.h>
#include <string>
#include <conio.h>
#include <sstream>
#include <iostream>
#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <winalleg.h>
#include <fstream>
using namespace std;
/*OBJETOS*/ //serán punteros a memoria
MIDI *musicaInicio;
MIDI *musicaJuego;
SAMPLE *sonido_Inicio... | [
"sergiolordi@hotmail.es"
] | sergiolordi@hotmail.es |
24772c1f8557b8289d0db19de681aa531bfa6684 | f532dfc68d8ad1a6e7b8aaf5b7dbc92fbf0efc62 | /win32_C++/ClassProJect02/ClassProJect02/CountingSort.cpp | 03f284a7cfee5b350629ad498015f6f3dcd8abdc | [] | no_license | NamYoonJae/InhaGame | 691fda687490fb70699f4018ac2888c0b08b5474 | 6e9872436cecccee44f97694f3a047a1d51d86ab | refs/heads/main | 2023-01-19T11:59:35.578386 | 2020-11-26T08:18:34 | 2020-11-26T08:18:34 | 305,272,697 | 0 | 0 | null | null | null | null | UHC | C++ | false | false | 1,280 | cpp | #include "stdafx.h"
#include <iostream>
#include <string>
#include <vector>
/*
계수 정렬
배열 중 가장 큰 수를 구한다
그 큰 수만큼의 배열을 만든다
arr1[6] = {1, 2, 3, 2, 4, 8} 배열이 주어진다
arr1에서 8이 가장 큰 수이다
arr2[]의 크기를 8로 지정해서 새로 생성한다
arr의 원소 숫자를 n 으로 칭하고
arr2[n] +=1 을 해준다
arr2의 방 번호에 있는 숫자만큼 arr3에 담는다
arr2[0] == 1
arr2[1] == 3
arr2[2] == 4
... | [
"nyoonjae@naver.com"
] | nyoonjae@naver.com |
b82881bf564c6ee1f33aac6b86d353cbaeb40397 | 0fbbef9a7ea231d3b600d16999f3ce36855b41c2 | /include/mantella_bits/optimisationAlgorithm/populationBasedOptimisationAlgorithm/modifiedCuckooSearch.hpp | b362672a170e1d1f25ef3967f82f23277c8d4f8e | [
"MIT"
] | permissive | markusmarx/Mantella | 080d07d4f7b549eab4caf9bc49037a9368c64c9b | c43a2a54d26e494878526ea019fb6cf50c57fcb8 | refs/heads/master | 2021-01-17T07:59:18.335683 | 2015-07-15T11:41:21 | 2015-07-15T11:41:21 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 4,388 | hpp | namespace mant {
template <typename T>
class ModifiedModifiedCuckooSearch : public PopulationBasedOptimisationAlgorithm<T> {
public:
explicit ModifiedModifiedCuckooSearch(
const std::shared_ptr<OptimisationProblem<T>> optimisationProblem,
const unsigned int populationSize) noexcept;
... | [
"noehren@sra.uni-hannover-de"
] | noehren@sra.uni-hannover-de |
797c99ec3470c55aa08f19bde1f9b0f54204bd14 | f81124e4a52878ceeb3e4b85afca44431ce68af2 | /re110_2/64/U | e8a373665d86916e00b4520c538d4b68c4e8d773 | [] | no_license | chaseguy15/coe-of2 | 7f47a72987638e60fd7491ee1310ee6a153a5c10 | dc09e8d5f172489eaa32610e08e1ee7fc665068c | refs/heads/master | 2023-03-29T16:59:14.421456 | 2021-04-06T23:26:52 | 2021-04-06T23:26:52 | 355,040,336 | 0 | 1 | null | null | null | null | UTF-8 | C++ | false | false | 1,153,413 | /*--------------------------------*- C++ -*----------------------------------*\
========= |
\\ / F ield | OpenFOAM: The Open Source CFD Toolbox
\\ / O peration | Website: https://openfoam.org
\\ / A nd | Version: 7
\\/ M anipulation |
\*-------... | [
"chaseguy15"
] | chaseguy15 | |
9aaf48230e27d6029275d90f20f6fe2ff82c7119 | 46afcdeb9ac451fd23f66d50982ff54de1db4477 | /thin.cpp | 3a13bcf796bff2e9e1b708b1071bdb7812828d9d | [] | no_license | linyike/IP_Thinning | cbd75c0262dbbe170ad0aede146f584841a872d9 | 71d9998adc5e14eb435ffdd0535ab3347b97b716 | refs/heads/master | 2020-05-19T16:29:56.786794 | 2014-07-03T14:40:08 | 2014-07-03T14:40:08 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 11,847 | cpp | #include "stdafx.h"
#include <iostream>
#include <fstream>
#include <string>
using namespace std;
void readEchoImage(string inputfname, string echofname, int **&
imagedata, int& head1, int& head2, int& head3, int& head4){
int t1, t2;
ifstream inputfile(inputfname);
ofstream echofile(echofname);
inputfile >> ... | [
"kehz1990@gmail.com"
] | kehz1990@gmail.com |
87289426168950909cf7ba82d8c6f4c99bb4dba9 | a1c6c3e5dbee5e8ca705700f0a626d7c9a040e1b | /DFS/116 Populating Next Right Pointers in Each Node/main.cpp | 861a4ff7dbd832952c5040e22b91ff9d375f713f | [] | no_license | Novak666/leetcode | 00370458c3931eb2f29158232b8a397b5386a852 | aac04bdfb38794e6b9007a7a72ae0d50b459601d | refs/heads/master | 2021-07-05T17:56:19.309548 | 2019-03-13T02:07:12 | 2019-03-13T02:07:12 | 145,187,953 | 1 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 571 | cpp | #include <iostream>
using namespace std;
class Solution {
public:
void connect(TreeLinkNode *root) {
if(!root)
return;
while(root){
TreeLinkNode *head = root;
while(root){
if(!root->left) break;
root->left->next = root->right;
... | [
"huweiyu2008@163.com"
] | huweiyu2008@163.com |
91946e19450e7a12fbaf309fdfd2350e16a14045 | be929a315de3488820c5ab75749480d1c57dd89b | /Sender.h | 52960a7db1589e8d7525152d0c47e59724fd37ca | [] | no_license | parklicoste/Project-Denas | b40f6b820468bd2f49e368c405035fcdccc43216 | 73484b701e27202a7b039fa4b6f57dc6b381ebc2 | refs/heads/master | 2022-07-01T10:25:12.063619 | 2020-05-12T04:20:40 | 2020-05-12T04:20:40 | 263,229,909 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 62 | h | #ifndef SENDER_H
#define SENDER_H
class Sender
{
};
#endif
| [
"lhushalkumar0102@gmail.com"
] | lhushalkumar0102@gmail.com |
e25aee3ece4c09b52ca1f4748eae65f4a689c722 | 795535d17e9da8afe6d103dcf8f3dea8d435201f | /src/PauseMenu.h | b62f99b2a503996e3510e81a353ca3c94255a5cf | [] | no_license | LiudmilaMashkina/Runner | 4696033ac36a677d3a9001b913e11285721bcccf | abdcd83098bc3bac58ea315cdb563e3899426e11 | refs/heads/master | 2021-05-12T03:01:00.709510 | 2018-02-27T00:47:30 | 2018-02-27T00:47:30 | 117,604,929 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,340 | h | #pragma once
#include "GUI/ViewPort.h"
#include "SceneManager.h"
#include "Utils/MacroCreate.h"
#include "Utils/StrongPtr.h"
namespace gui
{
class ProgressBar;
class Button;
class Label;
}
namespace gui2
{
class Button;
class CheckBox;
}
class HeadUpDisplay;
class PauseMenu : public cocos2d::N... | [
"liudmilamashkina@gmail.com"
] | liudmilamashkina@gmail.com |
459ce2f7bd7c4c0d1722e7738ed38ece01915845 | 58a0ba5ee99ec7a0bba36748ba96a557eb798023 | /LeetCode-Challenges/2020/4. April/06_group_anagrams.cpp | f66f4eb24776f4367b6b386d3c556257f19f5f09 | [
"MIT"
] | permissive | adityanjr/code-DS-ALGO | 5bdd503fb5f70d459c8e9b8e58690f9da159dd53 | 1c104c33d2f56fe671d586b702528a559925f875 | refs/heads/master | 2022-10-22T21:22:09.640237 | 2022-10-18T15:38:46 | 2022-10-18T15:38:46 | 217,567,198 | 40 | 54 | MIT | 2022-10-18T15:38:47 | 2019-10-25T15:50:28 | C++ | UTF-8 | C++ | false | false | 464 | cpp | class Solution
{
public:
vector<vector<string>> groupAnagrams(vector<string> &strs)
{
unordered_map<string, vector<string>> anag;
vector<vector<string>> result;
for (string str : strs)
{
string s = str;
sort(s.begin(), s.end());
anag[s].emplace... | [
"samant04aditya@gmail.com"
] | samant04aditya@gmail.com |
6810c8adb80c2ad417982f4b8df6a66eb66f395a | 3cbaab897509eab89d1d9806a704ff339575d90e | /src/Polymer.h | 39ba284aec7019ed0cc9aa1f7993472e7d05b08f | [
"BSD-3-Clause",
"LicenseRef-scancode-unknown-license-reference",
"BSD-2-Clause"
] | permissive | heliosfa/osprey-dpd | 7d2ac48eff0a9e89f1d5670ec8db695a6c8d14e8 | 2ae5cfd117423bcfb836f5d626e52bd579a9344a | refs/heads/main | 2023-03-03T23:27:24.454419 | 2021-02-10T09:06:06 | 2021-02-10T09:06:06 | null | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 5,956 | h | // Polymer.h: interface for the CPolymer class.
//
//////////////////////////////////////////////////////////////////////
#if !defined(AFX_POLYMER_H__A2FACF41_3F61_11D3_820E_0060088AD300__INCLUDED_)
#define AFX_POLYMER_H__A2FACF41_3F61_11D3_820E_0060088AD300__INCLUDED_
// Forward declarations
class ISimBoxBase;
cla... | [
"julian.shillcock@epfl.ch"
] | julian.shillcock@epfl.ch |
ab50a471571bef471ede753c5d437185797196af | f0a5c4ce1a1f74bd73fe0eb35a08385c8b4070e6 | /C++/level2/hazi2/seqinfile.cpp | f842fe6d125eb867d4206f5a834f6eb23ee0e1e0 | [] | no_license | pumpuidev/referencia | 613fe4551f81459db63abed7f9b02c9f8efe1ddc | 769789e3b3f126750c4bda6daa211f9d023e64f5 | refs/heads/main | 2023-03-02T05:21:02.883613 | 2021-02-15T01:49:24 | 2021-02-15T01:49:24 | 305,376,917 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 725 | cpp | #include "seqinfile.h"
#include <cstdlib>
#include <iostream>
using namespace std;
SeqInFile::SeqInFile(const string &fname)
{
x.open(fname.c_str());
if(x.fail()){
cout << "Fájlnyitási hiba!\n";
exit(1);
}
}
void SeqInFile::read()
{
string word;
x >> word;
if ( !x.fail()) {
... | [
"ernest.prorok@gmail.com"
] | ernest.prorok@gmail.com |
76dcd3ef8ea5ac8d13fc5f7327a960ccbaa24a01 | 3dde0c96f0682fae153673e409986c901be4a463 | /MFC/14-BD1/Tabla.h | 51a0cd8500e4d3cb0974299f72763a2318213d33 | [
"MIT"
] | permissive | NestorJavier/Programacion_avanzada-Visual- | 1bd801c217ee98ae9be1d5cb9fe8187cb2f0fb04 | 1ccb8d41988d860689a6f8ef74bdd53da62c5214 | refs/heads/main | 2023-01-15T20:25:55.246800 | 2020-11-24T02:29:21 | 2020-11-24T02:29:21 | 315,493,914 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 1,241 | h | #if !defined(AFX_TABLA_H__EE13D13C_2DB0_456A_914C_4FDED63F05C7__INCLUDED_)
#define AFX_TABLA_H__EE13D13C_2DB0_456A_914C_4FDED63F05C7__INCLUDED_
#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// Tabla.h : header file
//
/////////////////////////////////////////////////////////////////////////////
// CTabla... | [
"Nestor.Mendez1@daikinapplied.com"
] | Nestor.Mendez1@daikinapplied.com |
01526d3ec22a1203f6df895c997bc910be446b31 | b2f8455b80b95d5a74728dbc42071431519c7c12 | /PatternsCompunded/Parking_Lot/Controller.h | e4ec6c1b13fac4634cab8a718481a5f945b91616 | [] | no_license | rintujrajan/DesignPattern | 9e0fc438e334100f9ed22bff2c88a09cab707c99 | 3235c669fb629dec36bd8c732d28ef25d07d8de0 | refs/heads/master | 2021-07-04T04:46:54.882961 | 2021-04-26T15:31:30 | 2021-04-26T15:31:30 | 233,381,259 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 263 | h | #pragma once
#include "Model.h"
#include "Parking.h"
#include <memory>
class Controller
{
private:
Parking *parking;
private:
void init();
void initModelData();
public:
Controller(/* args */);
~Controller();
void startApplication();
};
| [
"rintujrajan90@gmail.com"
] | rintujrajan90@gmail.com |
9f87bc2448a32cb29b3946e26e3104587f1e20b0 | a4e7be49609c987b448ad50d40a0336577e85742 | /cocos/platform/CCGLView.h | 5c2cfc68a67ddd1288f57bcd54fb65f8f8a195db | [] | no_license | cocos2d-cpp/mini | 5ec065734c1e17d2ee3b6ce6949511fd546741fa | 1ba95aee89ac421890f70f168d22ae6a3a2bbd13 | refs/heads/master | 2020-12-30T16:45:35.553512 | 2017-05-21T19:43:09 | 2017-05-21T19:43:09 | 91,020,340 | 0 | 0 | null | null | null | null | UTF-8 | C++ | false | false | 14,499 | h | /****************************************************************************
Copyright (c) 2010-2012 cocos2d-x.org
Copyright (c) 2013-2016 Chukong Technologies Inc.
http://www.cocos2d-x.org
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation file... | [
"yahont@users.noreply.github.com"
] | yahont@users.noreply.github.com |
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.